<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\Kelas;
use App\Models\User;
use App\Providers\RouteServiceProvider;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class RegisteredUserController extends Controller
{
    /**
     * Display the registration view.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('auth.register');
    }

    /**
     * Handle an incoming registration request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request)
    {
        $request->validate(
            [
                'name' => 'required|string|max:50',
                'email' => 'required|string|email|max:100|unique:users',
                'password' => 'required|string|confirmed|min:8',
                'no_wa' => 'required|numeric|digits_between:8,12',
            ],
            [
                'name.required' => 'Nama lengkap harus diisi',
                'name.string' => 'Nama lengkap harus berupa alphabet',
                'name.max' => 'Nama lengkap maksimal 50 karakter',
                'name.required' => 'Nama lengkap harus diisi',
                'no_wa.between' => 'Nomor Whatsapp harus antara 8-12 digit',
                'no_wa.numeric' => 'Nomor Whatsapp harus berupa angka',
            ]
        );

        $user = User::create(
            [
                'nama'  => strtolower($request->name),
                'email' => strtolower($request->email),
                'no_wa' => $request->no_wa,
                'alamat' => $request->alamat,
                'gender' => strtolower($request->gender),
                'tgl_lahir' => $request->tanggal_lahir,
                'province_id' => $request->id_provinsi,
                'city_id' => $request->id_kota,
                'role' => 'user',
                'active' => 1,
                'password' => Hash::make($request->password),
            ]
        );

        $kelas = Kelas::where('kode', 'trial')->firstOrFail();
        $kelas->users()->syncWithoutDetaching([$user->id]);

        Auth::login($user);

        event(new Registered($user));

        return redirect(RouteServiceProvider::HOME);
    }
}
