<?php

namespace App\Http\Controllers;

use App\Models\Kelas;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class KelasController extends Controller
{
    public function index()
    {
        $kelases = Kelas::orderBy('nama', 'DESC')->withCount('users')->get();

        return response([
            "message"   => "List semua kelas",
            "data"      => $kelases
        ], Response::HTTP_OK);
    }

    public function create(Request $request)
    {
        try {
            $kelas          = new Kelas;
            $kelas->nama    = $request->nama;
            if (!$request->kode) {
                $kelas->kode    = strtolower($request->tahun . '-' . str_replace(' ', '-', $request->nama));
            } else {
                $kelas->kode    = strtolower($request->kode);
            }
            $kelas->tahun   = strtolower($request->tahun);
            $kelas->save();

            return response([
                "message"   => "Berhasil membuat kelas",
                "data"      => $kelas
            ], Response::HTTP_CREATED);
        } catch (QueryException $th) {
            return response([
                "message"   => "Gagal membuat kelas",
                "data"      => $kelas
            ], Response::HTTP_NOT_IMPLEMENTED);
        }
    }

    public function createFromArray(Request $request)
    {
        try {
            $data_kelas = [];

            foreach ($request->data as $data) {
                $kelas          = new Kelas;

                $kelas->nama    = $data['nama'];

                $kelas->kode    = strtolower($data['tahun'] . '-' . str_replace(' ', '-', $data['nama']));

                $kelas->tahun   = strtolower($data['tahun']);
                $kelas->save();

                array_push($data_kelas, $kelas);
            }



            return response([
                "message"   => "Berhasil upload kelas",
                "data"      => $data_kelas
            ], Response::HTTP_CREATED);
        } catch (QueryException $th) {
            return response([
                "message"   => "Gagal membuat kelas",
                "data"      => $data_kelas
            ], Response::HTTP_NOT_IMPLEMENTED);
        }
    }

    public function destroy(Request $request)
    {
        try {
            $kelas  = Kelas::findOrFail($request->id);

            try {
                $kelas->delete();

                return response([
                    "message"   => "Berhasil menghapus kelas",
                    "data"      => $kelas
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal membuat kelas",
                    "data"      => $kelas
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Kelas tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }

    public function update(Request $request)
    {
        try {
            $kelas  = Kelas::findOrFail($request->id);

            try {
                $kelas->nama    = $request->nama;
                $kelas->tahun    = $request->tahun;
                $kelas->kode    = $request->kode;
                $kelas->save();

                return response([
                    "message"   => "Berhasil update kelas",
                    "data"      => $kelas
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal membuat kelas",
                    "data"      => $kelas
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Kelas tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }
}
