<?php

namespace App\Http\Controllers;

use App\Models\Kelas;
use App\Models\User;
use Illuminate\Auth\Events\Verified;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Symfony\Component\HttpFoundation\Response;

class KelasUserController extends Controller
{
    public function showUsersByKelas(Request $req, $kode)
    {
        try {
            $kelas = Kelas::where('kode', strtolower($kode))->firstOrFail();
            $users = [];

            foreach ($kelas->users as $user) {
                array_push($users, $user);
            }

            return response([
                "message"   => "List user dengan kode kelas $kode",
                "data"      => $users
            ], Response::HTTP_OK);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(["message" => "Kode kelas tidak ditemukan."], Response::HTTP_NOT_FOUND);
        }
    }

    public function showKelasByUser(Request $req, $id)
    {
        try {
            $user = User::findOrFail($id);
            $kelas = [];

            foreach ($user->kelas as $kel) {
                array_push($kelas, $kel);
            }

            return response([
                "message"   => "List kelas dengan nama user: $user->nama",
                "data"      => $kelas
            ], Response::HTTP_OK);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(["message" => "user tidak ditemukan."], Response::HTTP_NOT_FOUND);
        }
    }

    public function destroyUserInKelas(Request $req, $kode)
    {
        try {
            $kelas = Kelas::where('kode', strtolower($kode))->firstOrFail();
            try {
                $kelas->users()->detach($req->id);
                return response([
                    "message"   => "Berhasil menghapus anggota kelas"
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menghapus anggota kelas"
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(["message" => "Kode kelas tidak ditemukan."], Response::HTTP_NOT_FOUND);
        }
    }

    public function searchUser(Request $req, $kode)
    {
        $email = $req->email;

        // $user = User::where('role', 'user')->where('email', 'LIKE', '%' . $email . '%')->orWhere('nama', 'LIKE', '%' . $email . '%')->whereDoesntHave('kelas', function ($q) use ($kode) {
        //     $q->where('kode', $kode);
        // })->first();

        $data = [];

        $users = User::where('role', 'user')->where(function ($q) use ($email) {
            $q->where('email', 'LIKE', '%' . $email . '%')->orWhere('nama', 'LIKE', '%' . $email . '%');
        })->get();

        foreach ($users as $user) {
            $present = false;

            foreach ($user->kelas as $kl) {
                if ($kl->kode == $kode) {
                    $present = true;
                }
            }

            if (!$present) {
                array_push($data, $user);
            }
        }

        if (count($data) == 0) {
            return response([
                "message"   => "Hasil pencarian user tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }

        return response([
            "message"   => "Hasil pencarian user",
            "data"      => $data[0]
        ], Response::HTTP_OK);
    }

    public function addMember(Request $req, $kode)
    {
        try {

            $kelas = Kelas::where('kode', $kode)->firstOrFail();
            try {
                $kelas->users()->syncWithoutDetaching([$req->id]);

                $user = User::find($req->id);

                return response([
                    "message"   => "Berhasil menambah anggota kelas",
                    "data"      => $user
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menambah anggota kelas"
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(["message" => "Kode kelas tidak ditemukan."], Response::HTTP_NOT_FOUND);
        }
    }

    public function importExcel(Request $req)
    {
        foreach ($req->data as $kode => $kelas) {
            $users_id = [];

            foreach ($kelas as $user) {
                $user_in_db = User::where('email', $user["email"])->first();

                if (!$user_in_db) {
                    $new_user           = new User;
                    $new_user->nama     = $user["nama"];
                    $new_user->email    = strtolower($user["email"]);
                    $new_user->password = Hash::make($user["password"]);
                    $new_user->role     = 'user';
                    $new_user->active   = true;
                    $new_user->save();
                    if ($user->markEmailAsVerified()) {
                        event(new Verified($user));
                    }

                    array_push($users_id, $new_user->id);
                } else {
                    array_push($users_id, $user_in_db->id);
                }
            }

            $kelas_in_db = Kelas::where('kode', $kode)->first();
            $kelas_in_db->users()->syncWithoutDetaching($users_id);
        }

        return response(["message"=>"Executed"]);
    }
}
