<?php

namespace App\Http\Controllers;

use App\Models\Materi;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class MateriController extends Controller
{
    public function index($id = null)
    {
        if ($id) {
            try {
                $materi = Materi::findOrFail($id);

                return response([
                    "message"   => "Data Materi",
                    "data"      => $materi
                ], Response::HTTP_OK);
            } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
                return response([
                    "message"   => "Materi dengan id: $id tidak ditemukan"
                ], Response::HTTP_NOT_FOUND);
            }
        } else {
            $materis = Materi::doesnthave('kelas')->get();

            return response([
                "message"   => "List Materi",
                "data"      => $materis
            ], Response::HTTP_OK);
        }
    }

    public function materiZoom(Request $request, $id = null)
    {
        if (!$id) {
            if (Auth::user()->role == 'user') {
                $user = Auth::user();
                $kelas = $user->kelas;

                $materi_kelas = [];

                foreach ($kelas as $kl) {
                    $materis = $kl->materis;

                    foreach ($materis as $materi) {
                        array_push($materi_kelas, $materi);
                    }
                }

                return response([
                    "message"   => "Materi by kelas user",
                    "data"      => $materi_kelas
                ], Response::HTTP_OK);
            }

            $materis = Materi::has('kelas')
                ->orderBy('judul', 'ASC')
                ->get();

            return response([
                "message"   => "List materi",
                "data"      => $materis
            ], Response::HTTP_OK);
        }

        try {
            $materi = Materi::findOrFail($id);
            return response([
                "message"   => "Materi dengan id: $id",
                "data"      => $materi
            ], Response::HTTP_OK);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Materi dengan id: $id tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }

    public function create(Request $request)
    {
        $materi              = new Materi;
        $materi->judul       = $request->judul;
        $materi->youtube_id   = $request->youtube_id;
        $materi->save();

        if ($request->kelas) {
            $id_kelas = [];

            foreach ($request->kelas as $kelas) {
                array_push($id_kelas, $kelas['id']);
            }

            $materi->kelas()->syncWithoutDetaching($id_kelas);
        }

        return response([
            "message"    => "Berhasil menambah materi",
            "data"       => $materi
        ], Response::HTTP_CREATED);
    }

    public function destroy(Request $request)
    {
        try {
            $materi = Materi::findOrFail($request->id);
            $materi->delete();

            return response([
                "message"   => "Berhasil menghapus materi",
                "data"      => $materi
            ], Response::HTTP_OK);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(
                [
                    "message"   => "Gagal menghapus ID not found!"
                ],
                Response::HTTP_NOT_FOUND
            );
        }
    }

    public function update(Request $request)
    {
        try {
            $materi             = Materi::findOrFail($request->id);
            $materi->judul      = $request->judul;
            $materi->youtube_id  = $request->youtube_id;
            $materi->save();

            if ($request->kelas) {
                $id_kelas = [];

                foreach ($request->kelas as $kelas) {
                    array_push($id_kelas, $kelas['id']);
                }

                $materi->kelas()->sync($id_kelas);
            }


            return response([
                "message"   => "Berhasil update materi",
                "data"      => $materi
            ], Response::HTTP_OK);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(
                [
                    "message"   => "data tidak ditemukan"
                ],
                Response::HTTP_NOT_FOUND
            );
        }
    }

    public function showKelasOfMateri($id)
    {
        try {
            $materi             = Materi::findOrFail($id);
            $data = [];

            foreach ($materi->kelas as $kelas) {
                array_push($data, $kelas);
            }

            return response([
                "message"   => "List kelas materi $id",
                "data"      => $data
            ], Response::HTTP_OK);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response(
                [
                    "message"   => "Data tidak ditemukan"
                ],
                Response::HTTP_NOT_FOUND
            );
        }
    }
}
