<?php

namespace App\Http\Controllers;

use App\Models\HasilLatihan;
use App\Models\JawabanUjianLatihan;
use App\Models\SoalLatihan;
use App\Models\UjianLatihan;
use App\Models\User;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class RiwayatController extends Controller
{
    public function latihan(Request $req, $kode)
    {
        $user   = Auth::user();
        return $this->cariRiwayatLatihan($user, $kode);
    }

    public function adminLatihan(Request $req, $kode, $user_id)
    {
        $user   = User::find($user_id);
        return $this->cariRiwayatLatihan($user, $kode);
    }

    public function listUserLatihan(Request $req, $kode)
    {
        $latihan = SoalLatihan::where("kode", $kode)->first();
        $latihan->kelas;
        $latihan->kelas->users;

        $users = User::whereHas('ujianLatihans', function ($q) use ($latihan) {
            $q->where('soal_latihan_id', $latihan->id);
        })->orderBy('nama')->get();

        $data   = [
            "id"    => $latihan->id,
            "kode"    => $latihan->kode,
            "nama"    => $latihan->nama,
            "paket_id"    => $latihan->paket_id,
            "kelas_id"    => $latihan->kelas_id,
            "tipe"    => $latihan->tipe,
            "kelas"    => [
                "kode"  =>  $latihan->kelas->id,
                "kode"  =>  $latihan->kelas->kode,
                "nama"  =>  $latihan->kelas->nama,
                "users"  =>  $users,
            ]
        ];

        return response([
            "message"   => "Data users",
            "data"      => $data
        ], Response::HTTP_OK);
    }

    private function cariRiwayatLatihan($user, $kode)
    {
        $latihan = SoalLatihan::where("kode", $kode)->first();
        $latihan->kelas;

        $ujian  = UjianLatihan::where("soal_latihan_id", $latihan->id)->where("user_id", $user->id)->orderBy("finished", "DESC")->get();

        $data = array();
        $data["ujian"] = [];
        $data["user"] = $user;
        $data["latihan"] = $latihan;

        foreach ($ujian as $uj) {
            if ($uj->hasil) {

                array_push(
                    $data["ujian"],
                    array_merge(
                        $uj->toArray(),
                        ["review_is_open" => (!$latihan || $latihan->end > time()) ? false : true]
                    )
                );
            }
        }

        return response([
            "message"   => "List riwayat pengerjaan",
            "data"      => $data
        ], Response::HTTP_OK);
    }

    public function hapusRiwayatLatihan(Request $req, $tryout_kode, $user_id)
    {

        $SoalLatihan    = SoalLatihan::where("kode", $tryout_kode)->firstOrFail();
        $ujian      = UjianLatihan::findOrFail($req->id);
        $hasil      = HasilLatihan::where('ujian_latihan_id', $ujian->id)->firstOrFail();
        $jawabans   = JawabanUjianLatihan::where('ujian_latihan_id', $ujian->id)->get();

        try {
            if ($hasil) {
                $hasil->delete();
            }
            foreach ($jawabans as $jawaban) {
                try {
                    $jawaban->delete();
                } catch (QueryException $th) {
                    return response([
                        "message"   => "Gagal menghapus hasil data jawaban ujian"
                    ], Response::HTTP_NOT_IMPLEMENTED);
                }
            }

            try {
                $ujian->delete();

                return response([
                    "message"   => "Berhasil menghapus riwayat ujian"
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menghapus hasil ujian"
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (QueryException $th) {
            return response([
                "message"   => "Gagal menghapus hasil ujian"
            ], Response::HTTP_NOT_IMPLEMENTED);
        }
    }
}
