<?php

namespace App\Http\Controllers;

use App\Models\SoalLatihan;
use App\Models\UjianLatihan;
use Carbon\Carbon;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;
use Symfony\Component\HttpFoundation\Response;

class SoalLatihanController extends Controller
{
    public function index(Request $req, $id_kategori, $tipe = 'reguler')
    {
        $user = Auth::user();
        $data = array();
        if ($user->role === 'user') {
            if ($tipe === 'bonus') {
                $latihans    = SoalLatihan::where('kategori_soal_id', $id_kategori)->where('tipe', 'bonus')->orderBy('created_at', 'DESC')->get();

                foreach ($latihans as $latihan) {
                    $latihan->kelas;
                    $latihan->paket;
                }
            }

            if ($tipe === 'reguler') {
                $latihans = [];
                foreach ($user->kelas as $kelas) {
                    $data_latihan = $kelas->soalLatihans->sortByDesc('start')->where('kategori_soal_id', $id_kategori)->where("tipe", 'reguler')->where('start', '<=', Carbon::now()->timestamp);
                    foreach ($data_latihan as $to) {
                        $to->kelas;
                        $to->paket;
                        array_push($latihans, $to);
                    }
                }
            }
        }

        if ($user->role === 'admin') {
            $latihans    = SoalLatihan::where('kategori_soal_id', $id_kategori)->where('tipe', $tipe)->orderBy('start', 'DESC')->get();
        }

        foreach ($latihans as $to) {

            $paket      = $to->paket;
            $soals      = $to->paket->soals;
            $d = array();
            $d = [
                "id"            => $to->id,
                "kode"          => $to->kode,
                "nama"          => $to->nama,
                "start"         => $to->start,
                "end"           => $to->end,
                "tipe"          => $to->tipe,
                "durasi"        => $to->durasi,
                "paket"         => [
                    "id"                => $paket->id,
                    "kode"              => $paket->kode,
                    "nama"              => $paket->nama,
                    "tipe"              => $paket->tipe,
                    "doc_pembahasan"    => $paket->doc_pembahasan,
                    "video_pembahasan"  => $paket->video_pembahasan,
                    "jumlah_soal"       => count($soals)
                ]
            ];

            if ($tipe === "reguler") {
                $kelas      = $to->kelas;


                $d["kelas"] = [
                    "id"    => $kelas->id,
                    "kode"  => $kelas->kode,
                    "tahun" => $kelas->tahun,
                    "nama"  => $kelas->nama,
                ];
            }

            array_push($data, $d);
        }

        return response([
            "message"   => "List Soal Latihan",
            "data"      => $data
        ], Response::HTTP_OK);
    }

    public function create(Request $req, $id_kategori, $tipe = 'reguler')
    {
        $latihan             = new SoalLatihan;
        $latihan->nama       = $req->nama;
        $latihan->paket_id   = $req->paket_id;

        if ($req->kelas_id) {
            $latihan->kelas_id   = $req->kelas_id;
        }

        $latihan->durasi     = $req->durasi;
        $latihan->kode     = Str::random(20);

        if ($req->start) {
            $latihan->start      = date("Y-m-d H:i:s", $req->start);
        }

        if ($req->end) {
            $latihan->end      = date("Y-m-d H:i:s", $req->end);
        }

        $latihan->tipe       = strtolower($tipe);

        $latihan->kategori_soal_id     = $id_kategori;
        $latihan->save();

        $paket      = $latihan->paket;
        $soals      = $latihan->paket->soals;

        $data = [
            "id"            => $latihan->id,
            "kode"          => $latihan->kode,
            "nama"          => $latihan->nama,
            "start"         => $latihan->start,
            "end"           => $latihan->end,
            "tipe"          => $latihan->tipe,
            "durasi"        => $latihan->durasi,
            "paket"         => [
                "id"                => $paket->id,
                "kode"              => $paket->kode,
                "nama"              => $paket->nama,
                "tipe"              => $paket->tipe,
                "doc_pembahasan"    => $paket->doc_pembahasan,
                "video_pembahasan"  => $paket->video_pembahasan,
                "jumlah_soal"       => count($soals)
            ]
        ];

        if ($tipe === "reguler") {
            $kelas      = $latihan->kelas;
            $data["kelas"] = [
                "id"    => $kelas->id,
                "kode"  => $kelas->kode,
                "tahun" => $kelas->tahun,
                "nama"  => $kelas->nama,
            ];
        }

        return response([
            "message"   => "Berhasil menambnah soal Latihan",
            "data"      => $data
        ], Response::HTTP_CREATED);
    }

    public function destroy(Request $req, $id_kategori)
    {
        try {
            $latihan = SoalLatihan::findorFail($req->id);
            try {

                $ujians = UjianLatihan::where('soal_latihan_id', $latihan->id)->get();

                foreach ($ujians as $ujian) {
                    $ujian->hasil()->delete();
                    $ujian->jawabanUjianLatihans()->delete();
                }

                $latihan->ujianLatihans()->delete();
                $latihan->delete();

                return response([
                    "message"   => "Berhasil menghapus"
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menghapus",
                    "error"     => $th
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Soal tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }

    public function update(Request $req, $kategori)
    {
        try {
            $latihan = SoalLatihan::findorFail($req->id);
            try {
                $latihan->nama       = $req->nama;
                $latihan->paket_id   = $req->paket_id;
                if ($req->kelas_id) {
                    $latihan->kelas_id   = $req->kelas_id;
                }
                $latihan->durasi     = $req->durasi;


                if ($req->start) {
                    $latihan->start      = date("Y-m-d H:i:s", $req->start);
                }

                if ($req->end) {
                    $latihan->end      = date("Y-m-d H:i:s", $req->end);
                }

                $latihan->save();

                $paket      = $latihan->paket;
                $soals      = $latihan->paket->soals;

                $data = [
                    "id"            => $latihan->id,
                    "kode"          => $latihan->kode,
                    "nama"          => $latihan->nama,
                    "start"         => $latihan->start,
                    "end"           => $latihan->end,
                    "tipe"          => $latihan->tipe,
                    "durasi"        => $latihan->durasi,
                    "paket"         => [
                        "id"                => $paket->id,
                        "kode"              => $paket->kode,
                        "nama"              => $paket->nama,
                        "tipe"              => $paket->tipe,
                        "doc_pembahasan"    => $paket->doc_pembahasan,
                        "video_pembahasan"  => $paket->video_pembahasan,
                        "jumlah_soal"       => count($soals)
                    ]
                ];

                if ($latihan->tipe === "reguler") {
                    $kelas      = $latihan->kelas;
                    $data["kelas"] = [
                        "id"    => $kelas->id,
                        "kode"  => $kelas->kode,
                        "tahun" => $kelas->tahun,
                        "nama"  => $kelas->nama,
                    ];
                }

                return response([
                    "message"   => "Berhasil update",
                    "data"      => $data
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal update",
                    "error" => $th
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Soal tidak ditemukan",
                "error" => $th
            ], Response::HTTP_NOT_FOUND);
        }
    }
}
