<?php

namespace App\Http\Controllers;

use App\Models\SoalTryout;
use App\Models\UjianTryout;
use Carbon\Carbon;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;
use Symfony\Component\HttpFoundation\Response;

class SoalTryoutController extends Controller
{
    public function index(Request $req, $tipe = 'reguler')
    {
        $user = Auth::user();
        $data = array();

        if ($user->role === 'user') {
            if ($tipe === 'bonus') {
                $tryouts    = SoalTryout::where('tipe', 'bonus')->orderBy('created_at', 'DESC')->get();

                foreach ($tryouts as $tryout) {
                    $tryout->paket;
                    $tryout->paket->pembahasan_tryout;
                }
            }
            if ($tipe === 'reguler') {
                $tryouts = [];
                foreach ($user->kelas as $kelas) {
                    foreach ($kelas->soalTryouts->sortByDesc('start')->where('tipe',  'reguler')->where('start', '<=', Carbon::now()->timestamp) as $to) {
                        $to->kelas;
                        $to->paket;
                        $to->paket->pembahasan_tryout;
                        array_push($tryouts, $to);
                    }
                }
            }
        }

        if ($user->role === 'admin') {
            $tryouts    = SoalTryout::where('tipe', 'reguler')->orderBy('start', 'DESC')->get();
        }

        foreach ($tryouts as $to) {

            $paket      = $to->paket;
            $soals      = $to->paket->soals;
            $pembahasan = $to->paket->pembahasan_tryout;
            $d = array();
            $d = [
                "id"            => $to->id,
                "kode"          => $to->kode,
                "nama"          => $to->nama,
                "start"         => $to->start,
                "end"           => $to->end,
                "tipe"          => $to->tipe,
                "durasi_km"     => $to->durasi_km,
                "durasi_kt"     => $to->durasi_kt,
                "durasi_ksk"    => $to->durasi_ksk,
                "durasi_tbs"    => $to->durasi_tbs,
                "paket"         => [
                    "id"                => $paket->id,
                    "kode"              => $paket->kode,
                    "nama"              => $paket->nama,
                    "tipe"              => $paket->tipe,
                    "doc_pembahasan"    => $paket->doc_pembahasan,
                    "pembahasan_tryout" => $pembahasan,
                    "jumlah_soal"       => count($soals)
                ]
            ];

            if ($tipe === "reguler") {
                $kelas      = $to->kelas;


                $d["kelas"] = [
                    "id"    => $kelas->id,
                    "kode"  => $kelas->kode,
                    "tahun" => $kelas->tahun,
                    "nama"  => $kelas->nama,
                ];
            }

            array_push($data, $d);
        }

        return response([
            "message"   => "List Soal Tryouts",
            "data"      => $data
        ], Response::HTTP_OK);
    }

    public function create(Request $req, $tipe = 'reguler')
    {
        $tryout             = new SoalTryout();
        $tryout->nama       = $req->nama;

        if ($req->kelas_id) {
            $tryout->kelas_id   = $req->kelas_id;
        }

        $tryout->paket_id   = $req->paket_id;

        $tryout->durasi_km     = $req->durasi_km;
        $tryout->durasi_kt     = $req->durasi_kt;
        $tryout->durasi_ksk     = $req->durasi_ksk;
        $tryout->durasi_tbs     = $req->durasi_tbs;
        $tryout->kode     = Str::random(20);

        if ($req->start) {
            $tryout->start      = date("Y-m-d H:i:s", $req->start);
        }

        if ($req->end) {
            $tryout->end      = date("Y-m-d H:i:s", $req->end);
        }


        $tryout->tipe       = strtolower($tipe);

        $tryout->save();

        $paket      = $tryout->paket;
        $soals      = $tryout->paket->soals;
        $pembahasan = $tryout->paket->pembahasan_tryout;

        $data = [
            "id"            => $tryout->id,
            "kode"          => $tryout->kode,
            "nama"          => $tryout->nama,
            "start"         => $tryout->start,
            "end"           => $tryout->end,
            "tipe"          => $tryout->tipe,
            "durasi_km"     => $tryout->durasi_km,
            "durasi_kt"     => $tryout->durasi_kt,
            "durasi_ksk"    => $tryout->durasi_ksk,
            "durasi_tbs"    => $tryout->durasi_tbs,
            "paket"         => [
                "id"                => $paket->id,
                "kode"              => $paket->kode,
                "nama"              => $paket->nama,
                "tipe"              => $paket->tipe,
                "doc_pembahasan"    => $paket->doc_pembahasan,
                "pembahasan_tryout" => $pembahasan,
                "jumlah_soal"       => count($soals)
            ]
        ];


        if ($tipe === "reguler") {
            $kelas      = $tryout->kelas;
            $data["kelas"] = [
                "id"    => $kelas->id,
                "kode"  => $kelas->kode,
                "tahun" => $kelas->tahun,
                "nama"  => $kelas->nama,
            ];
        }

        return response([
            "message"   => "Berhasil menambnah soal Tryout",
            "data"      => $data
        ], Response::HTTP_CREATED);
    }

    public function destroy(Request $req)
    {
        try {
            $tryout = SoalTryout::findorFail($req->id);
            try {
                $ujians = UjianTryout::where('soal_tryout_id', $tryout->id)->get();

                if ($ujians) {
                    foreach ($ujians as $ujian) {
                        $ujian->hasil()->delete();
                        $ujian->jawabanUjianTryouts()->delete();
                    }

                    $tryout->ujianTryouts()->delete();
                }
                $tryout->delete();

                return response([
                    "message"   => "Berhasil menghapus"
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menghapus",
                    "error"     => $th
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Soal tidak ditemukan",
                "error"     => $th
            ], Response::HTTP_NOT_FOUND);
        }
    }

    public function update(Request $req)
    {
        try {
            $tryout = SoalTryout::findorFail($req->id);
            try {
                $tryout->nama       = $req->nama;
                $tryout->paket_id   = $req->paket_id;
                if ($req->kelas_id) {
                    $tryout->kelas_id   = $req->kelas_id;
                }
                if ($req->start) {
                    $tryout->start      = date("Y-m-d H:i:s", $req->start);
                }

                if ($req->end) {
                    $tryout->end      = date("Y-m-d H:i:s", $req->end);
                }
                $tryout->durasi_km     = $req->durasi_km;
                $tryout->durasi_kt     = $req->durasi_kt;
                $tryout->durasi_ksk     = $req->durasi_ksk;
                $tryout->durasi_tbs     = $req->durasi_tbs;

                $tryout->save();

                $paket      = $tryout->paket;
                $soals      = $tryout->paket->soals;
                $pembahasan = $tryout->paket->pembahasan_tryout;

                $data = [
                    "id"            => $tryout->id,
                    "kode"          => $tryout->kode,
                    "nama"          => $tryout->nama,
                    "start"         => $tryout->start,
                    "end"           => $tryout->end,
                    "tipe"          => $tryout->tipe,
                    "durasi_km"     => $tryout->durasi_km,
                    "durasi_kt"     => $tryout->durasi_kt,
                    "durasi_ksk"    => $tryout->durasi_ksk,
                    "durasi_tbs"    => $tryout->durasi_tbs,
                    "paket"         => [
                        "id"                => $paket->id,
                        "kode"              => $paket->kode,
                        "nama"              => $paket->nama,
                        "tipe"              => $paket->tipe,
                        "doc_pembahasan"    => $paket->doc_pembahasan,
                        "pembahasan_tryout" => $pembahasan,
                        "jumlah_soal"       => count($soals)
                    ]
                ];


                if ($tryout->tipe === "reguler") {
                    $kelas      = $tryout->kelas;
                    $data["kelas"] = [
                        "id"    => $kelas->id,
                        "kode"  => $kelas->kode,
                        "tahun" => $kelas->tahun,
                        "nama"  => $kelas->nama,
                    ];
                }

                return response([
                    "message"   => "Berhasil update",
                    "data"      => $data
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal update"
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Soal tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }
}
