<?php

namespace App\Http\Controllers;

use App\Models\HasilLatihan;
use App\Models\JawabanUjianLatihan;
use App\Models\SoalLatihan;
use App\Models\UjianLatihan;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class UjianLatihanController extends Controller
{

    public function getSoalUjian($kode_soal, $sesi)
    {
        try {
            $latihan    = SoalLatihan::where('kode', $kode_soal)->firstOrFail();

            $ujian      = UjianLatihan::where('user_id', Auth::user()->id)->where('soal_latihan_id', $latihan->id)->where('sesi', $sesi)->first();

            $now    = time();

            if ($ujian) {
                return response([
                    "message"   => "Sesi sudah selesai",
                    "is_finished"    => true,
                    "data"      => [
                        "ujian" => $ujian,
                        "soal_latihan" => [
                            "id"    => $latihan->id,
                            "kode"    => $latihan->kode,
                            "nama"    => $latihan->nama,
                            "kategori"    => [
                                "id"    =>  $latihan->kategoriSoal->id,
                                "nama"    =>  $latihan->kategoriSoal->nama,
                                "kode"    =>  $latihan->kategoriSoal->kode,
                            ],
                            "durasi"    => $latihan->durasi,
                            "tipe"    => $latihan->tipe,
                            "start"    => $latihan->start,
                            "end"    => $latihan->end,
                        ],
                    ],
                    "current_time"  => $now
                ], Response::HTTP_OK);
            }

            $paket      = $latihan->paket;
            $soals      = $paket->soals;


            $data   = array();

            $data["soal_latihan"] = [
                "id"    => $latihan->id,
                "kode"    => $latihan->kode,
                "nama"    => $latihan->nama,
                "kategori"    => [
                    "id"    =>  $latihan->kategoriSoal->id,
                    "nama"    =>  $latihan->kategoriSoal->nama,
                    "kode"    =>  $latihan->kategoriSoal->kode,
                ],
                "durasi"    => $latihan->durasi,
                "tipe"    => $latihan->tipe,
                "start"    => $latihan->start,
                "end"    => $latihan->end,
            ];

            $data["ujian"]  = [
                "sesi"          => $sesi,
                "finished"      => 0,
                "start"         => $now,
                "end"           => $now + ($latihan->durasi * 60)
            ];

            $data["paket"]  = [
                "id"            => $paket->id,
                "kode"          => $paket->kode,
                "nama"          => $paket->nama,
                "tipe"          => $paket->tipe,
                "jumlah_soal"   => count($soals),
                "soal"          => []
            ];

            foreach ($soals as $soal) {
                array_push($data["paket"]["soal"], [
                    "id"            => $soal->id,
                    "kategori"      => [
                        "id"    =>  $latihan->kategoriSoal->id,
                        "nama"    =>  $latihan->kategoriSoal->nama,
                        "kode"    =>  $latihan->kategoriSoal->kode,
                    ],
                    "pertanyaan"    => $soal->pertanyaan,
                    "pilihan"       => [
                        "a" => $soal->pil_a,
                        "b" => $soal->pil_b,
                        "c" => $soal->pil_c,
                        "d" => $soal->pil_d,
                        "e" => $soal->pil_e,
                    ],
                    "ragu"      => false,
                    "jawaban"   => '',
                    "time"      => 0
                ]);
            }

            return response([
                "message"   => "soal ujian",
                "is_finished"    => false,
                "data"    => $data,
                "current_time"  => $now
            ]);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "Soal latihan tidak ditemukan"
            ], Response::HTTP_OK);
        }
    }

    public function endSession(Request $req, $kode_soal, $sesi)
    {
        $jml_soal = count($req->jawaban);
        $total_waktu = 0;
        $rata_waktu = 0;
        $total_nilai = 0;
        $benar = 0;
        $salah = 0;
        $kosong = 0;

        try {
            $ujian                  = new UjianLatihan;
            $ujian->user_id         = Auth::user()->id;
            $ujian->soal_latihan_id = $req->soal_latihan_id;
            $ujian->sesi            = $req->ujian["sesi"];
            $ujian->start           = date("Y-m-d H:i:s", $req->ujian["start"]);
            $ujian->end             = date("Y-m-d H:i:s", $req->ujian["end"]);
            $ujian->finished        = date(
                "Y-m-d H:i:s",
                ($req->finished > $req->ujian["end"]) ? $req->ujian["end"] : $req->finished
            );
            $ujian->save();

            foreach ($req->jawaban as $jawab) {
                try {
                    $answer                     = new JawabanUjianLatihan;
                    $answer->ujian_latihan_id   = $ujian->id;
                    $answer->soal_id            = $jawab["id"];
                    $answer->time               = $jawab["time"];
                    $answer->ragu               = $jawab["ragu"];

                    $soal           = $answer->soal;

                    $nilai = 0;
                    $jwb = strtoupper($jawab["jawaban"]);

                    if ($jwb) {
                        if ($jwb === $soal->jawaban) {
                            $benar++;
                        } else {
                            $salah++;
                        }

                        if ($jwb === 'A') {
                            $nilai = $soal->poin_a;
                        } elseif ($jwb === 'B') {
                            $nilai = $soal->poin_b;
                        } elseif ($jwb === 'C') {
                            $nilai = $soal->poin_c;
                        } elseif ($jwb === 'D') {
                            $nilai = $soal->poin_d;
                        } elseif ($jwb === 'E') {
                            $nilai = $soal->poin_e;
                        } else {
                            $nilai = 0;
                        }
                    } else {
                        $nilai = 0;
                        $kosong++;
                    }

                    $answer->jawaban = $jwb;
                    $answer->nilai  = $nilai;
                    $answer->save();

                    $total_nilai += $nilai;
                } catch (QueryException $th) {
                    return response([
                        "message"   => "Gagal menyimpan jawaban",
                        "data"      => $th
                    ], Response::HTTP_NOT_IMPLEMENTED);
                }
            }


            $total_waktu = $ujian->finished - $ujian->start;

            if ($total_waktu > 0 || $jml_soal > 0) {
                $rata_waktu = $total_waktu / $jml_soal;
            }

            try {
                $result = new HasilLatihan;
                $result->ujian_latihan_id = $ujian->id;
                $result->jml_soal = $jml_soal;
                $result->total_nilai = $total_nilai;
                $result->total_waktu = $total_waktu;
                $result->rata_waktu = $rata_waktu;
                $result->benar = $benar;
                $result->salah = $salah;
                $result->kosong = $kosong;
                $result->save();

                return response([
                    "message"   => "Sesi berhasil disimpan"
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menyimpan hasil",
                    "data"      => $th,
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (QueryException $th) {
            return response([
                "message"   => "Gagal menyimpan sesi",
                "data"      => $th,
            ], Response::HTTP_NOT_IMPLEMENTED);
        }
    }

    public function getHasil(Request $req, $kode, $sesi)
    {
        $latihan = SoalLatihan::where("kode", $kode)->first();
        $ujian = UjianLatihan::where("sesi", $sesi)->where("user_id", Auth::user()->id)->first();
        $hasil = HasilLatihan::where("ujian_latihan_id", $ujian->id)->first();

        $data = [
            "latihan"    => $latihan,
            "ujian"     => $ujian,
            "hasil"    => $hasil
        ];

        return response([
            "message"   => "Hasil Latihan",
            "data"      => $data
        ]);
    }

    private function saveHasil($ujian_id, $jml_soal, $total_nilai, $total_waktu, $rata_waktu, $benar, $salah, $kosong)
    {
        try {
            $result = new HasilLatihan;
            $result->ujian_latihan_id = $ujian_id;
            $result->jml_soal = $jml_soal;
            $result->total_nilai = $total_nilai;
            $result->total_waktu = $total_waktu;
            $result->rata_waktu = $rata_waktu;
            $result->benar = $benar;
            $result->salah = $salah;
            $result->kosong = $kosong;
            $result->save();

            return response([
                "message"   => "Sesi berhasil disimpan"
            ], Response::HTTP_OK);
        } catch (QueryException $th) {
            return response([
                "message"   => "Gagal menyimpan hasil",
                "data"      => $th,
            ], Response::HTTP_NOT_IMPLEMENTED);
        }
    }
}
