<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Auth\Events\Verified;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Symfony\Component\HttpFoundation\Response;

class UserController extends Controller
{
    public function index()
    {
        $users  = User::orderBy('nama', 'Asc')
            ->orderBy('role', 'Asc')->get();
        $data = array();
        foreach ($users as $key => $value) {
            array_push($data, [
                "id"        => $value->id,
                "nama"      => $value->nama,
                "gender"    => $value->gender,
                "tgl_lahir" => $value->tgl_lahir,
                "no_wa"     => $value->no_wa,
                "alamat"    => $value->alamat,
                "role"      => $value->role,
                "avatar"    => $value->avatar,
                "active"    => $value->active,
                "email"     => $value->email,
                "verified"  => $value->email_verified_at ? true : false
            ]);
        }

        return response([
            "message"   => "list User",
            "data"      => $data
        ], Response::HTTP_OK);
    }

    public function showByrole($role)
    {
        $users  = User::where('role', strtolower($role))
            ->orderBy('nama', 'Asc')->get();

        $data = array();
        foreach ($users as $key => $value) {
            array_push($data, [
                "id"        => $value->id,
                "nama"      => $value->nama,
                "gender"    => $value->gender,
                "tgl_lahir" => $value->tgl_lahir,
                "no_wa"     => $value->no_wa,
                "alamat"    => $value->alamat,
                "role"      => $value->role,
                "avatar"    => $value->avatar,
                "active"    => $value->active,
                "email"     => $value->email,
                "verified"  => $value->email_verified_at ? true : false
            ]);
        }

        if (count($users) < 1) {
            return response([
                "message"   => "list User dengan Role : $role tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }

        return response([
            "message"   => "list User dengan Role : $role",
            "data"      => $data
        ], Response::HTTP_OK);
    }

    public function cekEmail(Request $request)
    {
        $mail   = User::where('email', strtolower($request->email))->first();

        return response([
            "message"   => "email",
            "data"     => $mail
        ], Response::HTTP_OK);
    }

    public function create(Request $request)
    {
        $user           = new User;
        $user->nama     = $request->nama;
        $user->email    = strtolower($request->email);
        $user->password = Hash::make($request->password);
        $user->role     = strtolower($request->role);
        $user->active   = $request->active;

        if ($request->gender) {
            $user->gender     = strtolower($request->gender);
        }

        if ($request->tgl_lahir) {
            $user->tgl_lahir    = $request->tgl_lahir;
        }

        if ($request->no_wa) {
            $user->no_wa    = $request->no_wa;
        }

        if ($request->alamat) {
            $user->alamat     = strtolower($request->alamat);
        }

        if ($request->avatar) {
            $user->avatar     = $request->avatar;
        }

        $user->save();

        if ($user->markEmailAsVerified()) {
            event(new Verified($user));
        }

        $data = [
            "id"        => $user->id,
            "nama"      => $user->nama,
            "gender"    => $user->gender,
            "tgl_lahir" => $user->tgl_lahir,
            "no_wa"     => $user->no_wa,
            "alamat"    => $user->alamat,
            "role"      => $user->role,
            "avatar"    => $user->avatar,
            "active"    => $user->active,
            "email"     => $user->email,
            "verified"  => $user->email_verified_at ? true : false
        ];

        return response([
            "message"  => "Berhasil menambah user",
            "data"  => $data
        ], Response::HTTP_CREATED);
    }

    public function createFromArray(Request $request)
    {
        try {
            $users = [];

            foreach ($request->data as $data) {
                $user           = new User;
                $user->nama     = $data['nama'];
                $user->email    = strtolower($data['email']);
                $user->password = Hash::make($data['password']);
                $user->role     = strtolower($data['role']);
                $user->active   = $data['active'];

                $user->save();

                if ($user->markEmailAsVerified()) {
                    event(new Verified($user));
                }

                array_push($users, $user);
            }

            return response([
                "message"   => "Berhasil upload user",
                "data"      => $users
            ], Response::HTTP_CREATED);
        } catch (QueryException $th) {
            return response([
                "message"   => "Gagal upload user"
            ], Response::HTTP_NOT_IMPLEMENTED);
        }
    }

    public function destroy(Request $request)
    {
        try {
            $user  = User::findOrFail($request->id);

            try {
                $user->delete();

                return response([
                    "message"   => "Berhasil menghapus user",
                    "data"      => $user
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal menghapus user",
                    "data"      => $user
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "User tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }

    public function update(Request $request)
    {
        try {
            $user  = User::findOrFail($request->id);

            try {
                $user->nama     = $request->nama;
                $user->email    = strtolower($request->email);

                if ($request->password) {
                    $user->password = Hash::make($request->password);
                }

                $user->role     = strtolower($request->role);
                $user->active   = $request->active;

                if ($request->gender) {
                    $user->gender     = strtolower($request->gender);
                }

                if ($request->tgl_lahir) {
                    $user->tgl_lahir    = $request->tgl_lahir;
                }

                if ($request->no_wa) {
                    $user->no_wa    = $request->no_wa;
                }

                if ($request->alamat) {
                    $user->alamat     = strtolower($request->alamat);
                }

                if ($request->avatar) {
                    $user->avatar     = $request->avatar;
                }

                $user->save();

                return response([
                    "message"   => "Berhasil update user",
                    "data"      => $user
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal update user",
                    "data"      => $user
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "User tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }

    public function toggleActive(Request $req)
    {
        try {
            $user  = User::findOrFail($req->id);

            try {
                $user->active     = $req->active;
                $user->save();

                return response([
                    "message"   => "Berhasil ubah status",
                    "data"      => $user
                ], Response::HTTP_OK);
            } catch (QueryException $th) {
                return response([
                    "message"   => "Gagal ubah status",
                    "data"      => $user
                ], Response::HTTP_NOT_IMPLEMENTED);
            }
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $th) {
            return response([
                "message"   => "User tidak ditemukan"
            ], Response::HTTP_NOT_FOUND);
        }
    }
}
