Vue.component("v-pagination", {
    props: {
        maxVisibleButtons: {
            type: Number,
            required: false,
            default: 3
        },
        total: {
            type: Number,
            required: true
        },
        perPage: {
            type: Number,
            required: true
        },
        currentPage: {
            type: Number,
            required: true
        }
    },
    computed: {
        totalPages() {
            return Math.ceil(this.total / this.perPage)
        },
        startPage() {
            let maxButtons = (this.totalPages < this.maxVisibleButtons) ? this.totalPages : this
                .maxVisibleButtons

            if (this.currentPage === 1) {
                return 1;
            }

            if (this.currentPage === this.totalPages) {
                return this.totalPages - maxButtons + 1;
            }

            return this.currentPage - 1;
        },
        endPage() {
            let maxButtons = (this.totalPages < this.maxVisibleButtons) ? this.totalPages : this
                .maxVisibleButtons

            return Math.min(
                this.startPage + maxButtons - 1,
                this.totalPages
            );
        },
        pages() {
            const range = [];

            for (let i = this.startPage; i <= this.endPage; i += 1) {
                range.push({
                    name: i,
                    isDisabled: i === this.currentPage
                });
            }

            return range;
        },
        isInFirstPage() {
            return this.currentPage === 1;
        },
        isInLastPage() {
            return this.currentPage === this.totalPages;
        }
    },
    methods: {
        onClickFirstPage() {
            this.$emit("pagechanged", 1);
        },
        onClickPreviousPage() {
            this.$emit("pagechanged", this.currentPage - 1);
        },
        onClickPage(page) {
            this.$emit("pagechanged", page);
        },
        onClickNextPage() {
            this.$emit("pagechanged", this.currentPage + 1);
        },
        onClickLastPage() {
            this.$emit("pagechanged", this.totalPages);
        },
        isPageActive(page) {
            return this.currentPage === page;
        }
    },
    template: `
    <nav>
    <ul class="pagination justify-content-center mb-0">
        <li class="page-item" :class="{'disabled d-none':isInFirstPage}">
            <button class="page-link" @click="onClickFirstPage">
                <i class="fas fa-angle-double-left"></i>
            </button>
        </li>

        <li class="page-item" :class="{'disabled d-none':isInFirstPage}">
            <button class="page-link" @click="onClickPreviousPage">
                <i class="fas fa-angle-left"></i>
            </button>
        </li>

        <li
            v-for="page in pages"
            class="page-item"
            :class="{ active: isPageActive(page.name)}"
        >
            <button
                :disabled="page.isDisabled"
                class="page-link"
                @click="onClickPage(page.name)"
            >
                {{ page . name }}
            </button>
        </li>

        <li class="page-item" :class="{'disabled d-none':isInLastPage}">
            <button class="page-link" @click="onClickNextPage">
                <i class="fas fa-angle-right"></i>
            </button>
        </li>

        <li class="page-item" :class="{'disabled d-none':isInLastPage}">
            <button class="page-link" @click="onClickLastPage">
                <i class="fas fa-angle-double-right"></i>
            </button>
        </li>
    </ul>
</nav>

            `

});