@extends('dashboard.components.layout')

@section('title')
Dashboard - Pembagian Kelas
@endsection

@section('style')
<link rel="stylesheet" href="{{ asset('assets/css/theme-sugar.css') }}" type="text/css">
<link rel="stylesheet" href="{{ asset('assets/css/element-ui/index.css') }}" type="text/css">

@endsection

@section('search-box')
<div class="navbar-search navbar-search-light form-inline mr-sm-3" id="navbar-search-main">
    <div class="form-group mb-0" :class="{'focused':table.filters[0].value||table.filters[0].focus}">
        <div class="input-group input-group-alternative input-group-merge">
            <div class="input-group-prepend">
                <span class="input-group-text"><i class="fas fa-search"></i></span>
            </div>
            <input @@blur.self="table.filters[0].focus = false" @@click="table.filters[0].focus=true" v-model.trim="table.filters[0].value" class="form-control" placeholder="Cari Data User" type="text">

            <div v-if="table.filters[0].value" class="input-group-append mr-2 d-none d-md-flex" @@click="table.filters[0].value =  ''">
                <button class="input-group-text"><i class="fas fa-backspace"></i></button>
            </div>

            <div class="input-group-append d-md-none d-flex">
                <button v-if="table.filters[0].value" @@click="table.filters[0].value =  ''" class="input-group-text pr-0 pl-2"><i class="fas fa-backspace"></i></button>

                <button data-action="search-close" class="mr-2 input-group-text"><i class="fas fa-times"></i></button>
            </div>
        </div>
    </div>
    {{-- <button class="close ml-0 px-0 mr-1" data-target="#navbar-search-main"
            aria-label="Close">
            <i class="fas fa-times text-default" data-action="search-close"></i>
        </button> --}}
</div>
@endsection

@section('mobile-search')
@include('dashboard.components.mobile-search')

@endsection

@section('page-title')
<h6 class="h2 text-white d-inline-block mb-0">{{ strtoupper(Request::segment(3)) }}</h6>
@endsection

@section('breadcrumb')
<li class="breadcrumb-item text-white">
    <i class="fas fa-users"></i>
</li>
<li class="breadcrumb-item text-white">{{ ucfirst(Request::segment(1)) }}</li>
<li class="breadcrumb-item text-white">
    <a href="{{url('/master/kelas')}}">{{ ucfirst(Request::segment(2)) }}
    </a>
</li>
<li class="breadcrumb-item text-white">{{ strtoupper(Request::segment(3)) }}</li>
@endsection

@section('action-bar')

<div class="mt-3 d-sm-none"></div>

<div v-if="isLoaded && !isFailed" class="d-flex justify-content-end">
    <download-excel :data="users" :name="'Data Anggota kelas'">
        <button class="m-1 btn btn-sm btn-neutral">Export Data</button>
    </download-excel>

</div>
@endsection

@section('content')
<div class="mb-4">
    <div class="d-flex justify-content-center" v-if="!isLoaded && !isFailed" :class="{'d-none' : isLoaded && !isFailed}">
        <div class="col-12 card">
            <div class="card-body text-center">
                <div class="spinner">
                    <div class="rect1 bg-primary"></div>
                    <div class="rect2 bg-primary"></div>
                    <div class="rect3 bg-primary"></div>
                    <div class="rect4 bg-primary"></div>
                    <div class="rect5 bg-primary"></div>
                </div>
                <h4 class="mt-4 text-primary">
                    Sedang memuat data..
                </h4>
            </div>
        </div>
    </div>

    <div class="d-flex justify-content-center d-none" :class="{'d-block':isFailed}" v-if="isFailed">
        <div class="col-12 card">
            <div class="card-body text-center text-warning">
                <i class="mt-4 fas fa-exclamation-triangle fa-5x"></i>
                <h4 class="mt-4 text-warning">
                    Gagal memuat data. Silahkan refresh halaman.
                </h4>
            </div>
        </div>
    </div>

    <div v-if="isLoaded" class="d-none" :class="{'d-block':isLoaded}">
        <div class="row">
            <div class="col-md-8 col-sm-12">
                <div class="card">
                    <div class="card-header">
                        <h3 class="text-primary">List Anggota Kelas (@{{ users . length }} anggota)</h3>
                    </div>

                    <div class="card-body">
                        <data-tables ref="dt" style="width: 100%" :page-size.sync="table.pagination.perPage" :current-page.sync="table.pagination.current" @@current-page-change="handleCurrentPageChange" :filters="table.filters" :table-props="table.props" :data="users" :pagination-props="table.pagination">

                            <el-table-column label="User" min-width="200%" prop="nama" sortable="true">
                                <template slot-scope="scope">
                                    <div class="table-user d-flex justify-content-start align-items-center">
                                        <div>
                                            <img v-if="scope . row . avatar" :src="scope . row . avatar" class="avatar avatar-sm rounded-circle mr-2">

                                            <div v-else class="align-middle mr-2 avatar avatar-sm bg-primary rounded-circle">
                                                @{{ getInitialName(scope . row . nama) }}
                                            </div>
                                        </div>

                                        <div class="h5 text-primary">@{{ scope . row . nama . toUpperCase() }}</div>
                                    </div>
                                </template>
                            </el-table-column>

                            <el-table-column label="Email" min-width="200%" prop="email" sortable="true">
                                <template slot-scope="scope">
                                    <span>@{{ scope . row . email }}</span>
                                </template>
                            </el-table-column>

                            <el-table-column label="Gender" min-width="100%" prop="nama" sortable="gender">
                                <template slot-scope="scope">
                                    <span class="h3">
                                        <span v-if="scope.row.gender" class="badge badge-pill" :class="(scope . row . gender == 'laki-laki')?'badge-primary':(scope . row . gender == 'perempuan')?'badge-danger':''">
                                            <i class="fas" :class="(scope . row . gender == 'laki-laki')?'fa-mars':(scope . row . gender == 'perempuan')?'fa-venus':''"></i>
                                            <span>@{{ scope . row . gender . toUpperCase() }}</span>

                                        </span>
                                        <span v-else class="badge badge-pill badge-secondary">
                                            <i class="fas fa-genderless"></i>
                                            <span>Not Set</span>
                                        </span>
                                    </span>
                                </template>
                            </el-table-column>

                            <!-- <el-table-column label="Akses" min-width="100%" prop="nama" sortable="akses">
                                <template slot-scope="scope">
                                    <span class="h3">
                                        <span class="badge badge-pill" :class="(scope . row . role == 'admin')?'badge-primary':(scope . row . role == 'user')?'badge-warning':''">
                                            @{{ scope . row . role . toUpperCase() }}
                                        </span>
                                    </span>
                                </template>
                            </el-table-column> -->

                            <!-- <el-table-column label="Active" min-width="80%" prop="active" sortable="true">
                                <template slot-scope="scope">
                                    <label class="custom-toggle d-flex align-item-center">
                                        <input type="checkbox" @@change="toggleActive(scope.row)" v-model="scope . row . active">
                                        <span class="custom-toggle-slider rounded-circle" data-label-off="No" data-label-on="Yes"></span>
                                    </label>
                                </template>
                            </el-table-column> -->

                            <el-table-column label="Actions" min-width="100%">
                                <template slot-scope="scope">
                                    <el-tooltip class="item" effect="dark" content="Keluarkan user dari kelas ini" placement="top">
                                        <button @@click="confirmRemove(scope.row)" type="button" class="mr-0 btn btn-outline-danger btn-sm btn-icon-only">
                                            <span class="btn-inner--icon"><i class="fas fa-user-times"></i></span>
                                        </button>
                                    </el-tooltip>

                                    <!-- <el-tooltip class="item" effect="dark" content="Edit Akun" placement="top">
                                        <button @@click="editUser(scope.row)" type="button" class="btn btn-outline-primary btn-sm btn-icon-only">
                                            <span class="btn-inner--icon"><i class="fas fa-pencil-alt"></i></span>
                                        </button>
                                    </el-tooltip> -->
                                </template>
                            </el-table-column>

                        </data-tables>
                    </div>

                    <div class="card-footer d-flex  justify-content-around align-items-end pt-2">

                        <div class="col-md-2 col-sm-6 px-2 d-flex flex-column">
                            <label class="h5" for="perpage">Item/Halaman</label>

                            <select id="perpage" v-model="table.pagination.perPage" class="form-control form-control-sm" id="inlineFormCustomSelect">
                                <option v-for="item in pageSizes.length" :key="item" :value="pageSizes[item-1]">
                                    @{{ pageSizes[item - 1] + '/page' }}</option>
                            </select>
                        </div>

                        <div class="col-md-8 col-sm-12 d-flex flex-column justify-content-center text-center">
                            <h5>Jumlah data: @{{ users . length }}</h5>
                            <paginate :value="table.pagination.current" :page-count="numberPages" :page-range="3" :click-handler="clickCallback" :prev-text="''" :next-text="''" :container-class="'pagination justify-content-center mb-0'" :page-class="'page-item'" :page-link-class="'page-link btn-sm'" :prev-class="'page-item'" :prev-link-class="'fas fa-angle-left page-link'" :next-class="'page-item'" :next-link-class="'fas fa-angle-right page-link'" :hide-prev-next="false" :break-view-text="''" :break-view-link-class="'fas fa-ellipsis-h'">
                            </paginate>
                        </div>

                        <div class="col-md-2 col-sm-6 px-2 d-flex flex-column">
                            <label class="h5" for="to-page">Ke Halaman</label>
                            <input type="number" min="1" max="numberPage" v-model.number="table.pagination.current" id="to-page" class="form-control form-control-sm">
                        </div>

                    </div>

                </div>
            </div>

            <div class="col-md-4 col-sm-12">
                <div class="card">
                    <div class="card-header">
                        <h3 class="text-primary">Tambah Anggota</h3>
                    </div>
                    <div class="card-header py-0">
                        <form @@submit.prevent="searchNewMember">
                            <div class="form-group mb-0">
                                <div class="input-group input-group-lg input-group-flush">
                                    <div class="input-group-prepend">
                                        <div class="input-group-text">
                                            <span class="fas fa-search"></span>
                                        </div>
                                    </div>
                                    <input type="search" class="form-control" placeholder="Cari anggota baru" v-model="search.newMember.value">
                                </div>
                            </div>
                        </form>
                    </div>
                    <div class="card-body">
                        <ul class="list-group list-group-flush list my--3">
                            <div class="list-group-item p-2">
                                <li class="row align-items-center" v-if="search.newMember.result.nama">
                                    <div class="col-auto">
                                        <img v-if="search.newMember.result.avatar" :src="search.newMember.result.avatar" class="avatar rounded-circle mr-2">

                                        <div v-else class="align-middle mr-2 avatar bg-primary rounded-circle">
                                            @{{ getInitialName(search . newMember . result . nama) }}
                                        </div>


                                    </div>
                                    <div class="col ml--2 text-truncate">
                                        <h4 class="mb-0">
                                            <a href="#!" class="text-uppercase">@{{ search . newMember . result . nama }}</a>
                                        </h4>
                                        <small>
                                            @{{ search . newMember . result . email }}
                                        </small>
                                    </div>
                                    <div class="col-auto">
                                        <button type="button" class="btn btn-sm btn-primary" @@click="addMember(search . newMember . result)">
                                            <i class="fas fa-user-plus"></i>
                                        </button>
                                    </div>
                                </li>

                                <li class="row align-items-center" v-else>
                                    <div class="col-12" v-if="search.newMember.isSearching">
                                        <div class="text-center">
                                            <div class="spinner m-auto">
                                                <div class="rect1 bg-primary"></div>
                                                <div class="rect2 bg-primary"></div>
                                                <div class="rect3 bg-primary"></div>
                                                <div class="rect4 bg-primary"></div>
                                                <div class="rect5 bg-primary"></div>
                                            </div>
                                            <h4 class="mt-4 text-primary">
                                                Sedang mencari user..
                                            </h4>

                                        </div>

                                    </div>
                                </li>
                            </div>

                        </ul>
                    </div>
                </div>

            </div>

        </div>

        <confirm-delete v-if="form.remove.confirm" :show-modal="form.remove.confirm" :is-deleting="form.remove.isDeleting" @@onclose="closeConfirmRemove" @@onconfirm="removeMember">
        </confirm-delete>



    </div>
</div>

@endsection

@section('script')
<script src="{{ asset('assets/js/element-ui/index.js') }}"></script>
<script src="{{ asset('assets/js/element-ui/locales/en.js') }}"></script>
<script src="{{ asset('assets/js/element-ui/data-tables.js') }}"></script>

<script src="{{ asset('assets/js/vue-json-excel.umd.js') }}"></script>
<script src="{{ asset('assets/js/vue-paginate.js') }}"></script>
<script src="{{ asset('assets/js/vue-toast-notification.js') }}"></script>
<script src="{{ asset('assets/js/vue/confirm-delete.js') }}"></script>

<script>
    let base_url = "{{ url('/') }}/api/kelas_user/kelas/{{ Request::segment(3) }}"

    ELEMENT.locale(ELEMENT.lang.en)
    Vue.use(DataTables.DataTables)
    Vue.use(VueToast);
    Vue.component('paginate', VuejsPaginate)
    Vue.component('download-excel', JsonExcel)


    var app = new Vue({
        el: '#panel',
        data: {
            users: [],
            search: {
                value: '',
                focus: '',
                newMember: {
                    value: '',
                    isSearching: false,
                    result: {}
                }
            },
            table: {
                header: [],
                props: {

                },
                filters: [{
                    prop: ['nama', 'email', 'gender', 'role', 'active'],
                    value: '',
                    focus: false
                }],
                pagination: {
                    pageSizes: [10, 30, 50],
                    current: 1,
                    perPage: 10
                }
            },
            pagination: {
                current: 1,
                perPage: 8,
                numPages: 0
            },
            tablea: {
                pagination: {
                    pageSizes: [10, 30, 50],
                    current: 1,
                    perPage: 10
                }
            },
            form: {
                remove: {
                    confirm: false,
                    isDeleting: false,
                    data: {}
                },
                isSumitting: false
            },
            isFailed: false,
            isLoaded: false,
        },
        methods: {
            clickCallback(page) {
                this.table.pagination.current = page
            },
            handleCurrentPageChange(page) {
                this.table.pagination.current = page
            },
            showToast(msg, type) {
                Vue.$toast.open({
                    message: msg,
                    type: type,
                    // all of other options may go here
                });
            },
            async addMember(user) {
                this.form.is_submitting = true

                await axios
                    .post(
                        "{{ url('/') }}/api/kelas_user/kelas/tambah/{{ Request::segment(3) }}", {
                            id: user.id
                        })
                    .then((response) => {
                        this.users.push(response.data.data)

                        this.search.newMember.value = ''

                        this.showToast(
                            `Berhasil menambah anggota users.<br>Nama: ${response.data.data.nama}`,
                            'info'
                        )

                    }, (error) => {
                        this.showToast('Gagal menambah anggota user', 'error')
                    })

            },
            async searchNewMember() {

                if (this.search.newMember.value) {
                    this.search.newMember.isSearching = true
                    this.search.newMember.result = {}

                    await axios
                        .get(
                            "{{ url('/') }}/api/kelas_user/kelas/cari/{{ Request::segment(3) }}", {
                                params: {
                                    email: this.search.newMember.value
                                }
                            })
                        .then((response) => {

                            this.search.newMember.result = Object.assign({}, this.search.newMember
                                .result,
                                response.data.data)
                            this.search.newMember.isSearching = false

                        }, (error) => {
                            this.search.newMember.isSearching = false
                        })
                }

            },
            confirmRemove(user) {
                this.form.remove.data = user
                this.form.remove.confirm = true
            },
            closeConfirmRemove() {
                this.form.remove.data = {}
                this.form.remove.confirm = false
                this.form.remove.isDeleting = false
            },
            async removeMember() {
                this.form.remove.isDeleting = true

                let item = this.form.remove.data
                let id = this.users.indexOf(item)

                await axios
                    .delete(base_url, {
                        data: {
                            id: item.id
                        }
                    })
                    .then((response) => {
                        this.users.splice(id, 1)

                        this.showToast(
                            `Berhasil menghapus anggota.`,
                            'info'
                        )

                        this.closeConfirmRemove()

                    }, (error) => {
                        this.showToast('Gagal menghapus anggota', 'error')

                        this.closeConfirmRemove()
                    })
            },
            sortAnggota(data, properti, order) {
                if (order == 'asc' || order == '') {
                    return data.sort((a, b) => (a[properti] > b[properti]) ? 1 : -1)
                }
                if (order == 'desc') {
                    return data.sort((a, b) => (a[properti] > b[properti]) ? -1 : 1)
                }
            },
            getInitialName(fullName) {
                let name = fullName.split(' ')
                if (name.length > 1) {
                    return `${name[0].charAt(0).toUpperCase()}${name[1].charAt(0).toUpperCase()}`
                } else {
                    return `${name[0].charAt(0).toUpperCase()}${name[0].charAt(1).toUpperCase()}`
                }
            },
            async initialLoad() {
                await axios
                    .get(base_url)
                    .then((response) => {
                        this.users = response.data.data
                        this.isLoaded = true

                    }, (error) => {
                        this.isLoaded = false
                        this.isFailed = true
                    })
            }
        },
        computed: {
            sortedAnggota() {
                let sorted = [...this.filteredAnggota]

                return this.sortAnggota(sorted, 'nama', 'asc')
                // this.pagination.total = data.length
            },
            filteredAnggota() {
                let search = this.search.value.toLowerCase().trim()
                let filtered = [...this.users]

                if (!search) return this.users

                return filtered.filter(c => c.nama.toLowerCase().indexOf(search) > -1);
            },
            totalFiltered() {
                return this.sortedAnggota.length
            },
            numberPages() {
                return Math.ceil(this.users.length / this.table.pagination.perPage)
            },
            pageSizes() {
                if (this.users.length > 100) {
                    return [
                        5, 10, 30, 50, 100
                    ]
                }

                return [
                    5, 10, 30, 50, this.users.length
                ]
            }
        },
        watch: {
            'table.pagination.current'(newVal) {
                if (!newVal || newVal == 0) {
                    this.table.pagination.current = 1
                }
                if (newVal > this.numberPages) {
                    this.table.pagination.current = this.numberPages
                }
            },
            'search.newMember.value'(newVal) {
                if (!newVal) {
                    this.search.newMember.result = {}
                }
            }
        },
        created() {
            this.initialLoad()
        },
        updated() {

            if (this.$refs.dt.$refs.elPagination) {
                this.$refs.dt.$refs.elPagination.$el.className = 'd-none'
            }
        },
    })
</script>
@endsection
