@extends('dashboard.components.layout')

@section('title')
Dashboard - Materi Video
@endsection

@section('search-box')
<div class="navbar-search navbar-search-light form-inline mr-sm-3" id="navbar-search-main">
    <div class="form-group mb-0" :class="{'focused':search.value||search.focus}">
        <div class="input-group input-group-alternative input-group-merge">
            <div class="input-group-prepend">
                <span class="input-group-text"><i class="fas fa-search"></i></span>
            </div>
            <input @@blur.self="search.focus = false" @@click="search.focus=true" v-model.trim="search.value" class="form-control" placeholder="Cari materi" type="text">

            <div v-if="search.value" class="input-group-append mr-2 d-none d-md-flex" @@click="search.value =  ''">
                <button class="input-group-text"><i class="fas fa-backspace"></i></button>
            </div>

            <div class="input-group-append d-md-none d-flex">
                <button v-if="search.value" @@click="search.value =  ''" class="input-group-text pr-0 pl-2"><i class="fas fa-backspace"></i></button>

                <button data-action="search-close" class="mr-2 input-group-text"><i class="fas fa-times"></i></button>
            </div>
        </div>
    </div>
</div>
@endsection

@section('mobile-search')
@include('dashboard.components.mobile-search')
@endsection

@section('mobile-search')
@include('dashboard.components.mobile-search')
@endsection

@section('page-title')
<h6 class="h2 text-white d-inline-block mb-0">
    Materi Video
</h6>
@endsection

@section('breadcrumb')
<li class="breadcrumb-item text-white">
    <i class="fas fa-play"></i>
</li>
<li class="breadcrumb-item text-white">Materi</li>
<li class="breadcrumb-item text-white">Video</li>

@endsection

@section('action-bar')
<div v-if="isLoaded && !isFailed" class="d-none" :class="{'d-block':isLoaded && !isFailed}">
    <a href="#" class="m-1 btn btn-sm btn-neutral" @@click="sort.show=true">Urutkan</a>
</div>
@endsection

@section('content')
<div class="mb-4">
    <div class="d-flex justify-content-center" v-if="!isLoaded && !isFailed" :class="{'d-none' : isLoaded && !isFailed}">
        <div class="col-12 card">
            <div class="card-body text-center">
                <div class="spinner">
                    <div class="rect1 bg-primary"></div>
                    <div class="rect2 bg-primary"></div>
                    <div class="rect3 bg-primary"></div>
                    <div class="rect4 bg-primary"></div>
                    <div class="rect5 bg-primary"></div>
                </div>
                <h4 class="mt-4 text-primary">
                    Sedang memuat data..
                </h4>
            </div>
        </div>
    </div>

    <div class="d-flex justify-content-center d-none" :class="{'d-block':isFailed}" v-if="isFailed">
        <div class="col-12 card">
            <div class="card-body text-center text-warning">
                <i class="mt-4 fas fa-exclamation-triangle fa-5x"></i>
                <h4 class="mt-4 text-warning">
                    Gagal memuat data. Silahkan refresh halaman.
                </h4>
            </div>
        </div>
    </div>

    <div v-if="isLoaded" class="d-none" :class="{'d-block':isLoaded}">
        <div id="materi-area" class="card mb-0">
            <div class="card-body px-3 pb-0 pt-3">
                <div v-if="!pagePaginated.total" class="row">
                    <div class="col align-self-center">
                        <div v-if="search.value" class="h2 text-danger text-center d-flex flex-column align-items-center m-4 p-4">
                            <span><i class="far fa-sad-tear fa-4x mb-2"></i></span>
                            <p class="display-1 w-900 mb-0"></i> 404 - Not Found</p>
                            <span class="h3 text-default mb-4">Materi yang Anda cari tidak ditemukan</span>
                            <button @@click="search.value=''" class="btn btn-outline-primary">
                                Hapus Pencarian
                            </button>
                        </div>
                        <div v-if="!search.value" class="h2 text-danger text-center d-flex flex-column align-items-center m-4 p-4">
                            <span><i class="far fa-sad-tear fa-4x mb-2"></i></span>
                            <p class="display-1 w-900 mb-0"></i> 404 - Not Found</p>
                            <span class="h3 text-default mb-4">Materi belum tersedia</span>
                        </div>
                    </div>
                </div>
                <div v-else class="row">
                    <modal-video v-if="modal.show" :judul="modal.video.judul.toUpperCase()" :youtube_id="modal.video.youtube_id" v-on:close="closeModal">
                    </modal-video>

                    <div class="col-sm-6 col-md-3" v-for="(video, index) in pagePaginated.data" :key="index">
                        <div class="card mb-3">
                            <div class="div-hover" v-on:click="showModal(index)">
                                <div class="img-embed-container overlay-container">
                                    <img class="overlay-image card-img-top img-fluid" :src="'https://img.youtube.com/vi/'+video.youtube_id+'/sddefault.jpg'" width="400" height="300">
                                    <div class="overlay-middle">
                                        <button type="button" class="btn btn-youtube btn-icon">
                                            <span class="btn-inner--icon"><i class="fab fa-youtube"></i></span>
                                            <span class="btn-inner--text">Play</span>
                                        </button>
                                    </div>
                                </div>
                                <div class="card-body p-2">
                                    <h6 class="h4 card-title mb-0 text-primary text-truncate">
                                        @{{ video . judul . toUpperCase() }}
                                    </h6>
                                    <small class="text-muted h6">Uploaded at
                                        @{{ unixToDateTime(video . created_at) }}</small>
                                </div>
                            </div>
                        </div>
                    </div>

                </div>
            </div>

            <div v-if="sortedMateri.length > pagination.perPage">
                <div id="pagination" class="card-footer">
                    <paginate :value="pagination.current" :page-count="pagination.numPages" :page-range="3" :click-handler="onPageChange" :prev-text="''" :next-text="''" :container-class="'pagination justify-content-center mb-0'" :page-class="'page-item'" :page-link-class="'page-link btn-sm'" :prev-class="'page-item'" :prev-link-class="'fas fa-angle-left page-link'" :next-class="'page-item'" :next-link-class="'fas fa-angle-right page-link'" :hide-prev-next="false" :break-view-text="''" :break-view-link-class="'fas fa-ellipsis-h'">
                    </paginate>
                </div>
            </div>

        </div>

        <div v-if="sort.show" class="d-none" :class="{'d-block':sort.show}">
            <div class="modal fade show modal-active" tabindex="-1" role="dialog">
                <div class="modal-dialog modal-sm modal-dialog-centered" role="document">
                    <div class="modal-content">
                        <div class="modal-header py-2 px-3 align-items-center">
                            <h5 class="modal-title">
                                <span class="text-primary align-middle"> Urutkan Materi </span>
                            </h5>
                            <button type="button" class="close" @@click="sort.show=false">
                                <i class="fas fa-times-circle text-primary"></i>
                            </button>
                        </div>
                        <div class="modal-body px-3 pt-3 pb-0">
                            <select v-model="sort.by" class="custom-select mb-3">
                                <option disabled value="">Urutkan Bersarkan</option>
                                <option value="judul">Judul Materi</option>
                                <option value="created_at">Tanggal Upload</option>
                            </select>
                            <div class="custom-control custom-radio custom-control-inline">
                                <input v-model="sort.order" type="radio" id="ascending" name="order" class="custom-control-input" value="asc">
                                <label class="custom-control-label" for="ascending">Ascending</label>
                            </div>
                            <div class="custom-control custom-radio custom-control-inline">
                                <input v-model="sort.order" type="radio" id="descending" name="order" class="custom-control-input" value="desc">
                                <label class="custom-control-label" for="descending">Descending</label>
                            </div>
                        </div>
                        <div class="modal-footer p-3">
                            <button @@click="resetSort" type="button" class="btn btn-secondary" data-dismiss="modal">Reset</button>
                            <button @@click="sort.show=false" type="button" class="btn btn-primary">Tutup</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </div>
</div>

@endsection

@section('script')

<script src="{{ asset('assets/js/vue/modal-video.js') }}"></script>

<script src="{{ asset('assets/js/vue-paginate.js') }}"></script>

<script>
    let konten_url = "{{ url('/') }}/api/{{ Request::path() }}"
    let base_url = "{{ url('/') }}/api/materi"

    Vue.component('paginate', VuejsPaginate)

    var app = new Vue({
        el: '#panel',
        data: {
            pagination: {
                current: 1,
                total: 0,
                perPage: 8,
                numPages: 0
            },
            search: {
                value: '',
                focus: false
            },
            modal: {
                show: false,
                video: {}
            },
            sort: {
                show: false,
                by: 'judul',
                order: 'asc'
            },
            isFailed: false,
            isLoaded: false,
            materi: {
                data: []
            }
        },
        methods: {
            async getAllMateri() {
                const resp = await axios.get(base_url)
                return resp.data.data
            },
            onPageChange(page) {
                this.pagination.current = page;
            },
            paginator(items, current_page, per_page_items) {
                let page = current_page || 1,
                    per_page = per_page_items || 10,
                    offset = (page - 1) * per_page,

                    paginatedItems = items.slice(offset).slice(0, per_page_items),
                    total_pages = Math.ceil(items.length / per_page);

                this.pagination.numPages = total_pages
                // this.pagination.data = paginatedItems

                return {
                    total: items.length,
                    data: paginatedItems
                }
            },
            showModal(index) {
                this.modal.show = true
                this.modal.video = this.sortedMateri[index]
            },
            closeModal() {
                this.modal.show = false
                this.modal.video = {}
            },
            sortMateri(data, properti, order) {
                if (order == 'asc' || order == '') {
                    return data.sort((a, b) => (a[properti] > b[properti]) ? 1 : -1)
                }
                if (order == 'desc') {
                    return data.sort((a, b) => (a[properti] > b[properti]) ? -1 : 1)
                }
            },
            resetSort() {
                this.sort.by = 'judul'
                this.sort.order = 'asc'
            },
            async initialLoad() {
                await axios
                    .get(konten_url)
                    .then((response) => {
                        this.materi.data = response.data.data
                        this.pagination.total = response.data.data.length
                        this.isLoaded = true

                    }, (error) => {
                        this.isLoaded = false
                        this.isFailed = true
                    })
            },
            unixToDateTime(epoch) {
                let unix = epoch * 1000
                let dt = new Date(unix)

                return dt.toLocaleString('id-ID', {
                    dateStyle: 'short',
                    timeStyle: 'short'
                })

            }
        },
        computed: {
            sortedMateri() {
                let data = [...this.filteredMateri]
                let sorted = [...this.filteredMateri]

                if (this.sort.by) {
                    let data = this.sortMateri(sorted, this.sort.by, this.sort.order)
                    this.pagination.total = data.length

                    return data
                }
                return data
            },
            filteredMateri() {
                let search = this.search.value.toLowerCase().trim()
                let filtered = [...this.materi.data]

                if (!search) return this.materi.data

                return filtered.filter(c => c.judul.toLowerCase().indexOf(search) > -1);
            },
            pagePaginated() {
                let paginated = this.paginator(this.sortedMateri, this.pagination.current, this.pagination
                    .perPage)

                return paginated
            }
        },
        watch: {
            'pagination.numPages'(newVal) {
                if (this.pagination.current > newVal) {
                    this.pagination.current = newVal
                }
            }
        },
        mounted() {
            this.initialLoad()
        }
    })
</script>
@endsection
