@extends('dashboard.components.layout')

@section('title')
Dashboard - Rangking
@endsection

@section('style')
<link rel="stylesheet" href="{{ asset('assets/css/theme-sugar.css') }}" type="text/css">
<link rel="stylesheet" href="{{ asset('assets/css/element-ui/index.css') }}" type="text/css">

<style>
    .page-item .page-link {
        width: 2rem;
        height: 2rem;

        font-size: 0.75rem;
    }

    .overlay-container {
        position: relative;
    }

    .overlay-image {
        opacity: 1;
        display: block;

        transition: .5s ease;
        backface-visibility: hidden;
    }

    .overlay-middle {
        transition: .5s ease;
        opacity: 0;
        position: absolute;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        -ms-transform: translate(-50%, -50%);
        text-align: center;
    }

    .overlay-container:hover .overlay-image {
        opacity: 0.3;
    }

    .overlay-container:hover .overlay-middle {
        opacity: 1;
    }

    .overlay-text {
        background-color: #4CAF50;
        color: white;
        font-size: 16px;
        padding: 16px 32px;
    }
</style>

@endsection

@section('search-box')
<div class="navbar-search navbar-search-light form-inline mr-sm-3" id="navbar-search-main">
    <div class="form-group mb-0" :class="{'focused':table.filters[0].value||table.filters[0].focus}">
        <div class="input-group input-group-alternative input-group-merge">
            <div class="input-group-prepend">
                <span class="input-group-text"><i class="fas fa-search"></i></span>
            </div>
            <input @@blur.self="table.filters[0].focus = false" @@click="table.filters[0].focus=true" v-model.trim="table.filters[0].value" class="form-control" placeholder="Cari" type="text">

            <div v-if="table.filters[0].value" class="input-group-append mr-2 d-none d-md-flex" @@click="table.filters[0].value =  ''">
                <button class="input-group-text"><i class="fas fa-backspace"></i></button>
            </div>

            <div class="input-group-append d-md-none d-flex">
                <button v-if="table.filters[0].value" @@click="table.filters[0].value =  ''" class="input-group-text pr-0 pl-2"><i class="fas fa-backspace"></i></button>

                <button data-action="search-close" class="mr-2 input-group-text"><i class="fas fa-times"></i></button>
            </div>
        </div>
    </div>

</div>
@endsection

@section('mobile-search')
@include('dashboard.components.mobile-search')

@endsection

@section('page-title')
<h6 class="h2 text-white d-inline-block mb-0">
    @{{ (latihan && latihan.nama)?latihan.nama.toUpperCase():'' }}
</h6>
@endsection

@section('breadcrumb')
<li class="breadcrumb-item text-white">
    <i class="fas fa-chart-line"></i>
</li>
<li class="breadcrumb-item text-white">{{ ucfirst(Request::segment(1)) }}</li>
<li class="breadcrumb-item text-white">{{ ucfirst(Request::segment(2)) }}</li>
<li class="breadcrumb-item text-white">Rangking</li>
@endsection

@section('action-bar')

<div class="mt-3 d-sm-none"></div>

<div v-if="isLoaded && !isFailed" class="d-flex justify-content-end d-none" :class="{'d-block':isLoaded && !isFailed}">

    <el-tooltip class="item" effect="dark" placement="bottom">
        <div slot="content">Tampilkan rangking pengerjaan <br>pertama kali</div>

        <button @@click="rangkingPertama" class="m-1 btn btn-sm btn-neutral">Pertama Kali</button>
    </el-tooltip>

    <el-tooltip class="item" effect="dark" placement="bottom">
        <div slot="content">Tampilkan rangking pengerjaan pertama <br> berdasarkan rentang tanggal</div>
        <button @@click="tanggal.show = true" class="m-1 btn btn-sm btn-neutral">Berdasarkan Tanggal</button>
    </el-tooltip>


</div>
@endsection

@section('content')
<div class="mb-4">
    <div class="d-flex justify-content-center" v-if="!isLoaded && !isFailed" :class="{'d-none' : isLoaded && !isFailed}">
        <div class="col-12 card">
            <div class="card-body text-center">
                <div class="spinner">
                    <div class="rect1 bg-primary"></div>
                    <div class="rect2 bg-primary"></div>
                    <div class="rect3 bg-primary"></div>
                    <div class="rect4 bg-primary"></div>
                    <div class="rect5 bg-primary"></div>
                </div>
                <h4 class="mt-4 text-primary">
                    Sedang memuat data..
                </h4>
            </div>
        </div>
    </div>

    <div class="d-flex justify-content-center d-none" :class="{'d-block':isFailed}" v-if="isFailed">
        <div class="col-12 card">
            <div class="card-body text-center text-warning">
                <i class="mt-4 fas fa-exclamation-triangle fa-5x"></i>
                <h4 class="mt-4 text-warning">
                    Gagal memuat data. Silahkan refresh halaman.
                </h4>
            </div>
        </div>
    </div>

    <div v-if="isLoaded" class="d-none" :class="{'d-block':isLoaded}">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h3 class="text-primary">Peringkat</h3>
                    </div>
                    <div v-if="!loading">
                        <div class="card-body">
                            <data-tables ref="dt" style="width: 100%" :page-size.sync="table.pagination.perPage" :current-page.sync="table.pagination.current" @@current-page-change="handleCurrentPageChange" :filters="table.filters" :table-props="table.props" :data="rangking" :pagination-props="table.pagination">


                                <el-table-column label="Peringkat" min-width="120%" prop="peringkat " sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . peringkat }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Nama" min-width="200%" prop="nama" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . nama . toUpperCase() }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Poin 5" min-width="100%" prop="poin5" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . poin5 }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Poin 4" min-width="100%" prop="poin4" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . poin4 }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Poin 4" min-width="100%" prop="poin4" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . poin4 }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Poin 3" min-width="100%" prop="poin3" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . poin3 }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Poin 2" min-width="100%" prop="poin2" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . poin2 }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Poin 1" min-width="100%" prop="poin1" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . poin1 }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Kosong" min-width="100%" prop="kosong" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . kosong }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Nilai" min-width="100%" prop="total_nilai" sortable="true">
                                    <template slot-scope="scope">
                                        @{{ scope . row . total_nilai }}
                                    </template>
                                </el-table-column>

                                <el-table-column label="Durasi" min-width="100%" prop="total_waktu" sortable="true">
                                    <template slot-scope="scope">
                                        <h2>
                                            <span class="badge badge-pill badge-primary">
                                                <i class="fas fa-stopwatch mr-1">
                                                </i>
                                                <span>
                                                    @{{ scope . row . total_waktu }}
                                                </span>
                                            </span>
                                            </span>
                                        </h2>
                                    </template>
                                </el-table-column>



                            </data-tables>


                        </div>

                        <div class="card-footer d-flex  justify-content-around align-items-end pt-2">

                            <div class="col-md-2 col-sm-6 px-2 d-flex flex-column">
                                <label class="h5" for="perpage">Item/Halaman</label>

                                <select id="perpage" v-model="table.pagination.perPage" class="form-control form-control-sm" id="inlineFormCustomSelect">
                                    <option v-for="item in pageSizes.length" :key="item" :value="pageSizes[item-1]">
                                        @{{ pageSizes[item - 1] + '/page' }}</option>
                                </select>
                            </div>

                            <div class="col-md-8 col-sm-12 d-flex flex-column justify-content-center text-center">
                                <h5>Jumlah data: @{{ rangking . length }}</h5>
                                <paginate :value="table.pagination.current" :page-count="numberPages" :page-range="3" :click-handler="clickCallback" :prev-text="''" :next-text="''" :container-class="'pagination justify-content-center mb-0'" :page-class="'page-item'" :page-link-class="'page-link btn-sm'" :prev-class="'page-item'" :prev-link-class="'fas fa-angle-left page-link'" :next-class="'page-item'" :next-link-class="'fas fa-angle-right page-link'" :hide-prev-next="false" :break-view-text="''" :break-view-link-class="'fas fa-ellipsis-h'">
                                </paginate>
                            </div>

                            <div class="col-md-2 col-sm-6 px-2 d-flex flex-column">
                                <label class="h5" for="to-page">Ke Halaman</label>
                                <input type="number" min="1" max="numberPage" v-model.number="table.pagination.current" id="to-page" class="form-control form-control-sm">
                            </div>

                        </div>
                    </div>

                    <div v-else class="card-body">
                        <div class="spinner">
                            <div class="rect1 bg-primary"></div>
                            <div class="rect2 bg-primary"></div>
                            <div class="rect3 bg-primary"></div>
                            <div class="rect4 bg-primary"></div>
                            <div class="rect5 bg-primary"></div>
                        </div>
                        <h3 class="mt-4 mb-5 text-primary text-center">
                            Sedang memuat data..
                        </h3>
                    </div>
                </div>
            </div>

        </div>

        <div v-if="tanggal.show" class="d-none" :class="{'d-block':tanggal.show}">
            <div class="modal fade show modal-active" tabindex="-1" role="dialog">
                <div class="modal-dialog modal-sm modal-dialog-centered" role="document">
                    <div class="modal-content">
                        <div class="modal-header py-2 px-3 align-items-center">
                            <h5 class="modal-title">
                                <span class="text-primary align-middle">
                                    Tampilkan berdasarkan tanggal
                                </span>
                            </h5>
                            <button type="button" class="close" @@click="tanggal.show=false">
                                <i class="fas fa-times-circle text-primary"></i>
                            </button>
                        </div>
                        <div class="modal-body px-3 pt-3 pb-0">



                            <div class="form-group">
                                <label for="from">Mulai Tanggal</label>
                                <input v-model="tanggal.from" id="from" type="date" class="form-control">
                            </div>

                            <div class="form-group">
                                <label for="to">Hingga Tanggal</label>
                                <input v-model="tanggal.to" id="to" type="date" class="form-control">
                            </div>

                        </div>
                        <div class="modal-footer p-3">
                            <button @@click="tanggal.show =false" type="button" class="btn btn-secondary" data-dismiss="modal">Batal</button>
                            <button :disabled="!tanggal.from && !tanggal.to" type="button" @@click="rangkingTanggal(tanggal.from, tanggal.to)" class="btn btn-primary">Tampilkan</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </div>
</div>

@endsection

@section('script')
<script src="{{ asset('assets/js/element-ui/index.js') }}"></script>
<script src="{{ asset('assets/js/element-ui/locales/en.js') }}"></script>
<script src="{{ asset('assets/js/element-ui/data-tables.js') }}"></script>

<script src="{{ asset('assets/js/vue-paginate.js') }}"></script>

<script>
    let base_url = "{{ url('/') }}/api/user"
    let base = "{{ url('/') }}/api"

    let tryout_url = base + "/soal/latihan"
    let kode = "{{Request::segment(3)}}"
    let rangking = base + "/ujian/latihan/" + kode + "/rangking"

    ELEMENT.locale(ELEMENT.lang.en)
    Vue.use(DataTables.DataTables)
    Vue.component('paginate', VuejsPaginate)

    var app = new Vue({
        el: '#panel',
        data: {
            table: {
                header: [],
                props: {

                },
                filters: [{
                    prop: ['perinkat', 'nama', 'total_nilai', 'total_waktu', "benar", "salah", "kosong", "poin5", "poin4", "poin3", "poin2", "poin1"],
                    value: '',
                    focus: false
                }],
                pagination: {
                    pageSizes: [10, 30, 50],
                    current: 1,
                    perPage: 10
                }
            },
            tanggal: {
                show: false,
                from: '',
                to: ''
            },
            isFailed: false,
            isLoaded: false,
            loading: false,
            tryouts: [],
            rangking: [],
            latihan: [],
        },
        methods: {
            convertMenit(secs) {
                const sec = Math.round(secs)
                const m = Math.floor( sec/ 60)
                const s = sec - (m * 60)

                const str_m = m.toString()
                const str_s = s.toString()

                const menit = (str_m.length == 1) ? "0" + str_m : str_m
                const detik = (str_s.length == 1) ? "0" + str_s : str_s

                return menit + ':' + detik
            },
            timeStamp(time) {
                return Math.ceil(time / 1000)
            },
            clickCallback(page) {
                this.table.pagination.current = page
            },
            handleCurrentPageChange(page) {
                this.table.pagination.current = page
            },
            async rangkingPertama() {
                this.loading = true
                await axios
                    .get(rangking)
                    .then((response) => {
                        Vue.set(this, 'latihan', response.data.data.latihan)
                        Vue.set(this, 'rangking', response.data.data.rangking.map(
                            (item, i) => {
                                return {
                                    peringkat: i + 1,
                                    nama: item.user.nama,
                                    total_nilai: item.hasil.total_nilai,
                                    poin5: item.hasil.tkp_poin5,
                                    poin4: item.hasil.tkp_poin4,
                                    poin3: item.hasil.tkp_poin3,
                                    poin2: item.hasil.tkp_poin2,
                                    poin1: item.hasil.tkp_poin1,
                                    kosong: item.hasil.kosong,
                                    total_waktu: this.convertMenit(item.hasil.total_waktu),
                                }
                            }
                        ))

                        this.loading = false

                    }, (error) => {
                        this.loading = false
                    })
            },
            async rangkingTanggal() {
                this.tanggal.show = false
                this.loading = true
                await axios
                    .get(rangking, {
                        params: {
                            from: this.tanggal.from,
                            to: this.tanggal.to
                        }
                    })
                    .then((response) => {
                        Vue.set(this, 'latihan', response.data.data.latihan)
                        Vue.set(this, 'rangking', response.data.data.rangking.map(
                            (item, i) => {
                                return {
                                    peringkat: i + 1,
                                    nama: item.user.nama,
                                    total_nilai: item.hasil.total_nilai,
                                    poin5: item.hasil.tkp_poin5,
                                    poin4: item.hasil.tkp_poin4,
                                    poin3: item.hasil.tkp_poin3,
                                    poin2: item.hasil.tkp_poin2,
                                    poin1: item.hasil.tkp_poin1,
                                    kosong: item.hasil.kosong,
                                    total_waktu: this.convertMenit(item.hasil.total_waktu),
                                }
                            }
                        ))

                        this.loading = false

                    }, (error) => {
                        this.loading = false
                        this.tanggal.show = false
                    })
            },
            async initialLoad() {
                await axios
                    .get(rangking)
                    .then((response) => {
                        Vue.set(this, 'latihan', response.data.data.latihan)
                        Vue.set(this, 'rangking', response.data.data.rangking.map(
                            (item, i) => {
                                return {
                                    peringkat: i + 1,
                                    nama: item.user.nama,
                                    total_nilai: item.hasil.total_nilai,
                                    poin5: item.hasil.tkp_poin5,
                                    poin4: item.hasil.tkp_poin4,
                                    poin3: item.hasil.tkp_poin3,
                                    poin2: item.hasil.tkp_poin2,
                                    poin1: item.hasil.tkp_poin1,
                                    kosong: item.hasil.kosong,
                                    total_waktu: this.convertMenit(item.hasil.total_waktu),
                                }
                            }
                        ))

                        this.isLoaded = true

                    }, (error) => {
                        this.isLoaded = false
                        this.isFailed = true
                    })
            }
        },
        computed: {
            numberPages() {
                return Math.ceil(this.rangking.length / this.table.pagination.perPage)
            },
            pageSizes() {
                if (this.rangking.length > 100) {
                    return [
                        5, 10, 30, 50, 100
                    ]
                }

                return [
                    5, 10, 30, 50, this.rangking.length
                ]
            }
        },
        watch: {
            'table.pagination.current'(newVal) {
                if (!newVal || newVal == 0) {
                    this.table.pagination.current = 1
                }
                if (newVal > this.numberPages) {
                    this.table.pagination.current = this.numberPages
                }
            }
        },
        created() {
            this.initialLoad()
        },
        updated() {

            if (this.$refs.dt) {
                if (this.$refs.dt.$refs.elPagination) {
                    this.$refs.dt.$refs.elPagination.$el.className = 'd-none'
                }
            }
        },
    })
</script>
@endsection
