<?php

use App\Http\Controllers\AlamatController;
use App\Http\Controllers\KategoriSoalController;
use App\Http\Controllers\KelasController;
use App\Http\Controllers\KelasUserController;
use App\Http\Controllers\MateriController;
use App\Http\Controllers\PaketController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\RangkingController;
use App\Http\Controllers\ReviewController;
use App\Http\Controllers\RiwayatController;
use App\Http\Controllers\SoalLatihanController;
use App\Http\Controllers\SoalTryoutController;
use App\Http\Controllers\UjianLatihanController;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;


Route::prefix('api/alamat')->group(function () {
    Route::get('/provinsi', [AlamatController::class, "getProvinsi"]);
    Route::get('/kota/{id_provinsi}', [AlamatController::class, "getKota"])->whereNumber('id_provinsi');
});

Route::middleware(['auth', 'verified'])->group(function () {
    Route::get('/', function () {
        return view('dashboard.index');
    })->name('dashboard');

    Route::group([
        'middleware'    => 'role.check:web',
        'prefix'        => '/master'
    ], function () {
        Route::get('/kelas', function () {
            return view('dashboard.kelas.index');
        });

        Route::get('/kelas/{kode}', function () {
            return view('dashboard.kelas.pembagian.index');
        });

        Route::get('/akun', function () {
            return view('dashboard.akun.index');
        });

        Route::prefix('/paket')->group(function () {
            Route::get('/{tipe}', function ($tipe) {
                if ($tipe === 'latihan') {
                    return view('dashboard.paket.latihan.index');
                } elseif ($tipe === 'tryout') {
                    return view('dashboard.paket.to.index');
                }
            })->where('tipe', 'latihan|tryout');

            Route::get('/{tipe}/{paket}', function () {
                return view('dashboard.paket.viewer');
            });
        });
    });

    Route::middleware(['trial.check:web'])->group(function () {
        Route::prefix('/materi')->group(function () {
            Route::get('/text', function () {
                return view('dashboard.materi.user.text');
            });

            Route::get('/video', function () {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.materi.admin.video');
                }
                return view('dashboard.materi.user.video');
            });

            Route::get('/zoom', function () {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.materi.admin.zoom');
                }
                return view('dashboard.materi.user.zoom');
            });
        });
    });


    Route::prefix('/soal')->group(function () {
        Route::prefix('latihan')->group(function () {
            Route::get('/{id_kategori}', function () {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.soal.admin.harian');
                }
                return view('dashboard.soal.latihan.user');
            })->whereNumber('id_kategori');

            Route::get('/{id_kategori}/bonus', function () {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.soal.admin.bonus');
                }
                return view('dashboard.soal.latihan.userbonus');
            })->whereNumber('id_kategori')->middleware('trial.check:web');

            Route::get('/{kode_soal}/riwayat', function ($id) {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.riwayat.admin.latihan');
                }
                return view('dashboard.riwayat.latihan');
            });

            Route::get('/{kode_soal}/users', function ($id) {
                return view('dashboard.riwayat.users.latihan');
            })->middleware("role.check:web");

            Route::get('/{kode_soal}/analisis', function ($id) {
                return view('dashboard.soal.analisis.latihan');
            })->middleware("role.check:web");

            Route::get('/{kode_soal}/{user_id}/riwayat', function ($id) {
                return view('dashboard.riwayat.admin.latihan');
            })->whereNumber('user_id')->middleware("role.check:web");

            Route::get('/{kode_soal}/rangking', function () {
                return view('dashboard.rangking.latihan');
            });
        });

        Route::prefix('tryout')->group(function () {
            Route::get('/', function () {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.soal.tryout.admin');
                }
                return view('dashboard.soal.tryout.user');
            });

            Route::get('/bonus', function () {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.soal.tryout.adminbonus');
                }
                return view('dashboard.soal.tryout.userbonus');
            })->middleware('trial.check:web');

            Route::get('/{kode_soal}/riwayat', function ($id) {
                if (Auth::user()->role === 'admin') {
                    return view('dashboard.riwayat.admin.to');
                }
                return view('dashboard.riwayat.to');
            });

            Route::get('/{kode_soal}/users', function ($id) {
                return view('dashboard.riwayat.users.to');
            })->middleware("role.check:web");

            // Route::get('/{kode_soal}/analisis', function ($id) {
            //     return view('dashboard.soal.analisis.latihan');
            // })->middleware("role.check:web");

            Route::get('/{kode_soal}/{user_id}/riwayat', function ($id) {
                return view('dashboard.riwayat.admin.to');
            })->whereNumber('user_id')->middleware("role.check:web");

            Route::get('/{kode_soal}/rangking', function () {
                return view('dashboard.rangking.to');
            });
        });
    });

    Route::prefix('/ujian')->group(function () {
        Route::get('/latihan/{kode_soal}/start', function ($kode_soal) {
            $sesi = time();
            return redirect("ujian/latihan/$kode_soal/$sesi");
        });
        Route::get('/latihan/{kode_soal}/{sesi}', function () {
            if (Auth::user()->role === 'user') {
                return view('dashboard.ujian.latihan');
            }
            return redirect('/');
        })->whereNumber('sesi')->whereAlphaNumeric('kode_soal');

        Route::get('/latihan/{kode_soal}/{sesi}/review', function () {
            return view('dashboard.review.latihan');
        })->whereNumber('sesi')->whereAlphaNumeric('kode_soal');
    });

    Route::get('profile', function () {
        return view('dashboard.profile.index');
    });





    Route::prefix('/api')->group(function () {
        Route::get('kategori', [KategoriSoalController::class, "index"]);
        Route::prefix('/kelas')->group(function () {
            Route::get('/', [KelasController::class, 'index']);

            Route::middleware('role.check:api')->group(function () {
                Route::post('/', [KelasController::class, 'create']);
                Route::post('/array', [KelasUserController::class, 'importExcel']);
                Route::delete('/', [KelasController::class, 'destroy']);
                Route::put('/', [KelasController::class, 'update']);
            });
        });


        Route::middleware(['trial.check:api'])->group(function () {
            Route::prefix('/materi')->group(function () {
                Route::prefix('/video')->group(function () {
                    Route::get('/{id?}', [MateriController::class, 'index'])->whereNumber('id');

                    Route::middleware('role.check:api')->group(function () {
                        Route::post('/', [MateriController::class, 'create']);
                        Route::delete('/', [MateriController::class, 'destroy']);
                        Route::put('/', [MateriController::class, 'update']);
                    });
                });

                Route::prefix('/zoom')->group(function () {
                    Route::get('/{id?}', [MateriController::class, 'materiZoom'])->whereNumber('id');

                    Route::middleware('role.check:api')->group(function () {
                        Route::get('/{id}/kelas', [MateriController::class, 'showKelasOfMateri']);

                        Route::post('/', [MateriController::class, 'create']);
                        Route::delete('/', [MateriController::class, 'destroy']);
                        Route::put('/', [MateriController::class, 'update']);
                    });
                });
            });
        });

        Route::middleware('role.check:api')->group(function () {
            Route::prefix('/user')->group(function () {
                Route::get('/', [UserController::class, 'index']);
                Route::get('/email', [UserController::class, 'cekEmail']);
                Route::get('/{role}', [UserController::class, 'showByRole'])->where('role', 'admin|user');
                Route::post('/', [UserController::class, 'create']);
                Route::post('/array', [UserController::class, 'createFromArray']);
                Route::delete('/', [UserController::class, 'destroy']);
                Route::put('/', [UserController::class, 'update']);

                Route::put('/toogle-active', [UserController::class, 'toggleActive']);
            });

            Route::prefix('/kelas_user')->group(function () {
                Route::get('/kelas/{kode}', [KelasUserController::class, 'showUsersByKelas']);
                Route::get('/kelas/cari/{kode}', [KelasUserController::class, 'searchUser']);
                Route::post('/kelas/tambah/{kode}', [KelasUserController::class, 'addMember']);

                Route::get('/user/{id}', [KelasUserController::class, 'showKelasByUser']);

                Route::delete('/kelas/{kode}', [KelasUserController::class, 'destroyUserInKelas']);
            });

            Route::prefix('/paket')->group(function () {
                Route::get('/{tipe}', [PaketController::class, 'index'])->where('tipe', 'latihan|tryout');

                Route::post('/{tipe}', [PaketController::class, 'create']);
                Route::delete('/{tipe}', [PaketController::class, 'destroy']);
                Route::put('/{tipe}', [PaketController::class, 'update']);

                Route::get('/{kode}/soal', [PaketController::class, 'getSoalByPaket']);
                Route::post('/{kode}/soal', [PaketController::class, 'addSoal']);
                Route::delete('/{kode}/soal', [PaketController::class, 'destroySoal']);
                Route::put('/{kode}/soal', [PaketController::class, 'updateSoal']);
            });

            Route::prefix('/soal')->group(function () {
                // Route::prefix('/tryout')->group(function () {
                //     // Route::get('/{tipe?}', [TryoutController::class, 'index']);
                //     Route::post('/{tipe?}', [TryoutController::class, 'create']);
                //     Route::delete('/{tipe?}', [TryoutController::class, 'destroy']);
                //     Route::put('/{tipe?}', [TryoutController::class, 'update']);

                //     Route::get('/{tryout_kode}/users', [RiwayatController::class, 'listUserTo']);
                //     Route::get('/{tryout_kode}/{user_id}/riwayat', [RiwayatController::class, 'adminTo'])->whereNumber('user_id');
                //     Route::delete('/{tryout_kode}/{user_id}/riwayat', [RiwayatController::class, 'hapusRiwayatTo'])->whereNumber('user_id');

                //     Route::put('/{tryout_kode}/{user_id}/riwayat', [RiwayatController::class, 'hitungUlangTo'])->whereNumber('user_id');
                // });

                Route::prefix('/tryout')->group(function () {
                    Route::post('/{tipe?}', [SoalTryoutController::class, 'create']);
                    Route::delete('/{tipe?}', [SoalTryoutController::class, 'destroy']);
                    Route::put('/{tipe?}', [SoalTryoutController::class, 'update']);

                    Route::get('/{kode}/users', [RiwayatController::class, 'listUserLatihan']);
                    Route::get('/{kode}/{user_id}/riwayat', [RiwayatController::class, 'adminLatihan'])->whereNumber('user_id');
                    Route::delete('/{kode}/{user_id}/riwayat', [RiwayatController::class, 'hapusRiwayatLatihan'])->whereNumber('user_id');
                });

                Route::prefix('/latihan')->group(function () {
                    Route::post('/{id_kategori}/{tipe?}', [SoalLatihanController::class, 'create'])->whereNumber('id_kategori');
                    Route::delete('/{id_kategori}/{tipe?}', [SoalLatihanController::class, 'destroy'])->whereNumber('id_kategori');
                    Route::put('/{id_kategori}/{tipe?}', [SoalLatihanController::class, 'update'])->whereNumber('id_kategori');

                    Route::get('/{kode}/users', [RiwayatController::class, 'listUserLatihan']);
                    Route::get('/{kode}/{user_id}/riwayat', [RiwayatController::class, 'adminLatihan'])->whereNumber('user_id');
                    Route::delete('/{kode}/{user_id}/riwayat', [RiwayatController::class, 'hapusRiwayatLatihan'])->whereNumber('user_id');
                });
            });
        });

        Route::prefix('/soal')->group(function () {

            Route::prefix('/tryout')->group(function () {
                Route::get('/{tipe?}', [SoalTryoutController::class, 'index']);
            });

            Route::prefix('/latihan')->group(function () {
                Route::get('/{id_kategori}/{tipe?}', [SoalLatihanController::class, 'index'])->whereNumber('id_kategori');

                Route::get('/{kode_soal}/riwayat', [RiwayatController::class, 'latihan']);
            });
        });

        Route::middleware(['role.check:api'])->group(function () {
            Route::prefix('/analisis')->group(function () {
                Route::get('/latihan/{kode}', [RangkingController::class, 'analisisLatihan']);
            });
        });

        Route::prefix('/ujian')->group(function () {
            Route::prefix('/latihan')->group(function () {
                Route::get('/{kode_soal}/{sesi}', [UjianLatihanController::class, 'getSoalUjian'])->whereNumber('sesi');

                Route::post(
                    '/{kode_soal}/{sesi}',
                    [UjianLatihanController::class, 'endSession']
                )->whereNumber('sesi');

                Route::get('/{kode_soal}/rangking', [RangkingController::class, 'latihan']);

                Route::get('/{kode_soal}/{sesi}/review', [ReviewController::class, 'latihan']);
            });
        });

        Route::prefix('/profile')->group(function () {
            Route::post('/password', [ProfileController::class, 'ubahPassword']);
            Route::get('/user', [ProfileController::class, 'getUser']);
            Route::put('/update', [ProfileController::class, 'update']);
        });
    });
});




require __DIR__ . '/auth.php';
